function FaktorParticipacije
%DEFINICIJA
%
%   Funkcija "FaktorParticipacije" vrne faktorje participacije in efektivne
%   mase za posamezne nihajne oblike v odvisnosti od smeri delovanja
%   obremenitve konstrukcije (smeri gibanja tal X in Z).
%
%IZHODNI PODTAKI
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Fpart: Spremenljivka definirana kot matrika. Fpart(i,j) pomeni faktor 
%   participacije za nihajno obliko i in smer gibanja tal v smeri j.
%
% - Meff: Spremenljivka definirana kot matrika. Meff(i,j) pomeni efektivno 
%   maso za nihajno obliko i in smer gibanja tal v smeri j.

%definicija globalnih spremenljivk
global N
global M
global fi
global w
global PrSt
global Fpart
global Mef
global VsotaMas
global NOmin
global stmod
global LastnoNihanje

%Tvorjenje Masne matrike "Mred".
for i=1:stmod
    Mred(:,:,i)=M(PrSt,PrSt,i);
end    

%Tvorjenje smernega vektorja obtezbe
Ssplosni=[(diag(eye(N)))    (diag(zeros(N)));...
          (diag(zeros(N)))  (diag(eye(N)));...
          (diag(zeros(N)))  (diag(zeros(N)))];      
S=Ssplosni(PrSt,:); 

%Racun faktorjev participacije
for k=1:stmod
    for i=1:length(w(:,k))
        for j=1:2
            Fpart(i,j,k)=(fi(:,i,k))'*Mred(:,:,k)*S(:,j)./((fi(:,i,k))'*Mred(:,:,k)*fi(:,i,k));
        end
    end
end
global MefVsota

%Racun efektivnih mas
for k=1:stmod   
    for j=1:2
        for i=1:length(w(:,k))
            Mef(i,j,k)=(((fi(:,i,k))'*Mred(:,:,k)*S(:,j))^2./((fi(:,i,k))'*Mred(:,:,k)*fi(:,i,k)))/VsotaMas;
        end
        MefVsota(:,j,k)=cumsum(Mef(:,j,k));
    end
end

for k=1:stmod
    if all(MefVsota(:,1,k))==1&&all(MefVsota(:,2,k))==1
        for j=1:2
            nomin(j,k)=min(find(MefVsota(:,j,k)>0.90));
        end
    elseif all(MefVsota(:,1,k))==0&&all(MefVsota(:,2,k))==1
        nomin(j,k)=min(find(MefVsota(:,2,k)>0.90));
    elseif all(MefVsota(:,1,k))==1&&all(MefVsota(:,2,k))==0
        nomin(j,k)=min(find(MefVsota(:,1,k)>0.90));
    end
end

NOmin=max(max(nomin));

LastnoNihanje.FaktorjiParticipacije=Fpart';
LastnoNihanje.EfektivneMase=Mef';

