function IzracunajPremikeKonstrukcije
%DEFINICIJA
%
%   Funkcija "PomikiKonstrukcije" vrne vektorje pomikov konstrukcije za
%   pripadajoco nihajno obliko in smer gibanja tal. Upostevane so tri
%   prostostne stopnje v vsaki etazi in sicer dve translaciji v ravnini
%   plosce in rotacija okrog osi navpicno na plosco. Pomiki so racunani v
%   izhodiscu globalnega koordinatnega sistema.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - U: Spremenljivka je definirana kot tridimenzionalni seznam, v katerem
%   so razvrsceni vektorji pomikov konstrukcije za posamezno nihajno 
%   obliko in smer gibanja tal.
%
% - Ukomb:Spremenljivka je definirana kot vektor. Posamezne komponente
%   pomenijo kombinirane pomike konstrukcije v pripadajoci smeri.
%
% - Udej: Spremenljivka je definirana kot vektor. Posamezne komponente
%   pomenijo dejanske pomike konstrukcije v pripadajoci smeri.

%Definicija globalnih spremenljivk
global Fpart
global Sa
global Fi
global w
global qx
global qy
global N
global U
global Xcr
global Ycr
global Xt
global Yt
global UdejSrss
global UkombSrss
global UdejEc
global UkombEc
global Uno
global To
global drxEc
global dryEc
global drxSrss
global drySrss
global stm
global stmod
global PodatkiOKonstrukciji
global RezultatiAnalize
global SmerAnalize

stm=PodatkiOKonstrukciji.GlobalniPodatki.SteviloMakroelementov;

%Racun pomikov konstrukcije
for o=1:stmod
    for i=1:length(w(:,o))
        for j=1:2
            U(1:N,i,j,o)=Fi(1:N,i,o)*Fpart(i,j,o)*Sa(i,1,o)*9.81/(w(i,o))^2;
            U(N+1:2*N,i,j,o)=Fi(N+1:2*N,i,o)*Fpart(i,j,o)*Sa(i,2,o)*9.81/(w(i,o))^2;
            U(2*N+1:3*N,i,j,o)=Fi(2*N+1:3*N,i,o)*Fpart(i,j,o)*(Sa(i,1,o)+Sa(i,2,o))*9.81/(2*(w(i,o))^2);
        end
    end
end

%Kombinacija zaradi vpliva nihajnih oblik (CQC)
vsota=zeros(3*N,2,stmod);
for o=1:stmod
    for k=1:2
        for l=1:3*N
            for i=1:length(w(:,o))
                for j=1:length(w(:,o))
                    ceta=0.05; %koeficient kriticnega dusenja
                    r=w(j,o)/w(i,o); %razmerje frekvenc
                    ro(i,j)=((8*ceta^2)*(1+r)*r^(3/2))/((1-r^2)^2+4*(ceta^2)*r*(1+r)^2);
                    %ro je faktor, ki defnira sklopljenost posmeznih nihajnih oblik
                    vsota(l,k,o)=vsota(l,k,o)+ro(i,j)*U(l,i,k,o)*U(l,j,k,o);
                end
            end
        end
    end
end

for o=1:stmod
    for i=1:3*N
        for j=1:2
            Uno(i,j,o)=sqrt(vsota(i,j,o)); 
            %"Uno" pomeni kombinacijo pomikov konstrukcije zaradi razlicnih nihajnih oblik
        end
    end
end

%Kombinacija zaradi razlicnih smeri vzbujanja (SRSS)
for o=1:stmod
    for i=1:3*N
        UkombSrss(i,o)=sqrt((Uno(i,1,o))^2+(Uno(i,2,o))^2);
        %"Ukomb" pomeni kombinacijo pomikov zaradi nihajnih oblik in razlicnih
        %smeri vzbujanja po metodi SRSS
    end
end

%Kombinacija zaradi razlicnih smeri vzbujanja (EC8)
for o=1:stmod
    for i=1:3*N
        UkombEc(i,1,o)=1.0*Uno(i,1,o)+0.3*Uno(i,2,o);
        UkombEc(i,2,o)=0.3*Uno(i,1,o)+1.0*Uno(i,2,o);
        %"UkombEC" pomeni kombinacijo pomikov zaradi nihajnih oblik in razlicnih
        %smeri vzbujanja po metodi, ki je kot alternativa predlagana v EC8
    end
end

%Racun dejanskih pomikov SRSS in EC
for o=1:stmod
    UdejSrss(1:N,o)=qx.*UkombSrss(1:N,o);
    UdejSrss(N+1:2*N,o)=qy.*UkombSrss(N+1:2*N,o);
    UdejSrss(2*N+1:3*N,o)=((qx+qy)*0.5).*UkombSrss(2*N+1:3*N,o);
    
    UdejEc(1:N,:,o)=qx.*UkombEc(1:N,:,o);
    UdejEc(N+1:2*N,:,o)=qy.*UkombEc(N+1:2*N,:,o);
    UdejEc(2*N+1:3*N,:,o)=((qx+qy)*0.5).*UkombEc(2*N+1:3*N,:,o);
end

%Raun pomikov etae SRSS
for k=1:stmod
    for j=1:stm
        PomikEtazeSrss(:,j,k)=To(:,:,j)*UdejSrss(:,k);
        PomikEtazeSrssX(2:N+1,j,k)=PomikEtazeSrss(1:N,j,k);
        PomikEtazeSrssY(N+3:2*N+2,j,k)=PomikEtazeSrss(N+1:2*N,j,k);
        PomikEtazeSrssZ(2*N+4:3*N+3,j,k)=PomikEtazeSrss(2*N+1:3*N,j,k);
    end
end

%Raun pomikov etae EC8
for k=1:stmod
    for j=1:stm
        PomikEtazeEc(:,j,1,k)=To(:,:,j)*UdejEc(:,1,k);
        PomikEtazeEc(:,j,2,k)=To(:,:,j)*UdejEc(:,2,k);
        
        PomikEtazeEcX(2:N+1,j,1,k)=PomikEtazeEc(1:N,j,1,k);
        PomikEtazeEcY(N+3:2*N+2,j,1,k)=PomikEtazeEc(N+1:2*N,j,1,k);
        PomikEtazeEcZ(2*N+4:3*N+3,j,1,k)=PomikEtazeEc(2*N+1:3*N,j,1,k);
        
        PomikEtazeEcX(2:N+1,j,2,k)=PomikEtazeEc(1:N,j,2,k);
        PomikEtazeEcY(N+3:2*N+2,j,2,k)=PomikEtazeEc(N+1:2*N,j,2,k);
        PomikEtazeEcZ(2*N+4:3*N+3,j,2,k)=PomikEtazeEc(2*N+1:3*N,j,2,k);        
    end
end

% Izracun zamikov etaze:
for k=1:stmod
    for j=1:stm
        for i=1:N
            dsxSrss(i,j,k)=PomikEtazeSrssX(i+1,j,k)-PomikEtazeSrssX(i,j,k);
            dsySrss(i,j,k)=PomikEtazeSrssY(i+1,j,k)-PomikEtazeSrssY(i,j,k);
            dsxEc(i,j,1,k)=PomikEtazeEcX(i+1,j,1,k)-PomikEtazeEcX(i,j,1,k);
            dsyEc(i,j,1,k)=PomikEtazeEcY(i+1,j,1,k)-PomikEtazeEcY(i,j,1,k);
            dsxEc(i,j,2,k)=PomikEtazeEcX(i+1,j,2,k)-PomikEtazeEcX(i,j,2,k);
            dsyEc(i,j,2,k)=PomikEtazeEcY(i+1,j,2,k)-PomikEtazeEcY(i,j,2,k);             
        end
    end
end

%"povpreje" pomikov v posamezni etai
for k=1:stmod
    for i=1:N
        drxSrss(i,k)=sum(dsxSrss(i,:,k))/stm; 
        drySrss(i,k)=sum(dsySrss(i,:,k))/stm;
        drxEc(1,i,k)=sum(dsxEc(i,:,1,k))/stm;
        dryEc(1,i,k)=sum(dsyEc(i,:,1,k))/stm;
        drxEc(2,i,k)=sum(dsxEc(i,:,2,k))/stm;
        dryEc(2,i,k)=sum(dsyEc(i,:,2,k))/stm;         
    end
end

%Priprava podatkov za izpis:
if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
    if stmod==1        
        if any(Xcr(:,2)-diag(Xt))==0&&any(Ycr(:,2)-diag(Yt))==0; % ce ni rotacije
        else % ce je rotacija
            RezultatiAnalize.Premiki.Konstrukcija.Model1.KombinacijaSRSS=[UkombSrss([1:3*N],1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.KombinacijaEC=[UkombEc([1:3*N],:,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.ObremenitevX=[Uno([1:3*N],1,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.ObremenitevY=[Uno([1:3*N],2,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.Nekombinirani.ObremenitevX=[U(1:3*N,:,1,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.Nekombinirani.ObremenitevY=[U(1:3*N,:,2,1)];            
        end
    else
    end
elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1
    if stmod==1        
        if any(Xcr(:,2)-diag(Xt))==0 
            RezultatiAnalize.Premiki.Konstrukcija.Model1.KombinacijaSRSS=[UkombSrss([N+1:2*N],1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.KombinacijaEC=[UkombEc([N+1:2*N],:,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.ObremenitevY=[Uno([N+1:2*N],2,1)];
            RezultatiAnalize.Premiki.Konstrukcija.Model1.Nekombinirani.ObremenitevY=[U(N+1:2*N,:,2,1)];
        else 
        end
    else
    end
end