function NihajneOblike
%DEFINICIJA
%
%   Funkcija "LastnoNihanje" vrne lastne frekvence, nihajne ase in nihajne
%   oblike konstrukcije.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - w: Spremenljivka definirana kot vektor. Posamezne komponente pomenijo 
%   lastne frekvence (kotne hitrosti) pripadajocih nihajnih oblik 
%   konstrukcije.
%
% - Fi: Spremenljivka definirana kot matrika. Vsak stolpec pomeni
%   pripadajoco nihajno obliko konstrukcije.
%
% - T: Spremenljivka definirana kot vektor. Posamezne komponente pomenijo
%   nihajne ase pripadajocih nihajnih oblik konstrukcije.
%
% - PrSt: Spremenljivka je vektor. Posamezne komponente pomenijo upostevane
%   prostostne stopnje konstrukcije v dinamicni analaizi.

%definicija globalnih spremenljivk
global N
global K
global M
global w
global fi
global Fi
global T
global Xt
global Yt
global Xcr
global Ycr
global PrSt
global StPrSt
global stmod
global RezultatiAnalize
global SmerAnalize

%Racun nihajnih oblik konstrukcije in pripadajocih frekvenc

if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
    if any(Xcr(:,2)-diag(Xt))==0&&any(Ycr(:,2)-diag(Yt))==0;
    else     
        PrSt=[1:3*N];
        StPrSt=length(PrSt);
        for i=1:stmod
            [LastniVektor,LastnaVrednost]=eig(K,M(:,:,i));
            KroznaFrekvenca(:,i)=sqrt(diag(LastnaVrednost([find(LastniVektor(N+1,:,i)~=0)],[find(LastniVektor(N+1,:,i)~=0)],i)));
            [w(:,i),indeks(:,i)]=sort(sqrt(diag(LastnaVrednost(:,:,i))));
            Fi(:,:,i)=LastniVektor(:,indeks(:,i),i);
            T(:,i)=2*pi*w(:,i).^-1;
            fi(:,:,i)=Fi(:,:,i);
        end
    end

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1    
    if stmod==1        
        if any(Xcr(:,2)-diag(Xt))==0;
            PrSt=[N+1:2*N];
            StPrSt=length(PrSt);
            [LastniVektor,LastnaVrednost]=eig(K([PrSt],[PrSt]),M([PrSt],[PrSt]));
            [w,indeks]=sort(sqrt(diag(LastnaVrednost)));
            T=2*pi*w.^-1;
            fi(:,:)=LastniVektor(:,indeks);
            Fi=zeros(3*N,N);
            Fi(N+1:2*N,:)=fi(:,:);
        else
        end
    else
    end
end

%Normiranje lastnega vektorja
for i=1:stmod
    for j=1:length(w(:,i))
        fi(:,j,i)=fi(:,j,i)./max(abs(fi(:,j,i)));
        Fi(:,j,i)=Fi(:,j,i)./max(abs(Fi(:,j,i)));
    end
end

RezultatiAnalize.LastnoNihanje.NihajniCasi=T';
RezultatiAnalize.LastnoNihanje.NihajneOblike=fi;