function Okvir
%DEFINICIJA:
%
%   Funkcija "Okvir" vrne togostne in transformacijske matrike okvirja in 
%   podatke o geometriji. Vsi izhodni podatki so globalne spremenljivke. 
%
%VHODNI PODATKI:
%
% - MakroElement: Spremenljivka je skalar. Njena vrednost pomeni zaporedno 
%   tevilko makroelementa, ki ga podajamo v program.
%
% - koordinataX: Spremenljivka je skalar. Njena vrednost pomeni x-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%  
% - koordinataY: Spremenljivka je skalar. Njena vrednost pomeni y-koordinato
%   centra togosti okvirja v globalnem koordinatenem sistemu konstrukcije.
%
% - alfa: Spremenljivka je skalar. Njena vrednost pomeni kot med osjo 1
%   lokalnega koordinatnega sistema vozlisc makroelementa in osjo "X" globalnega
%   koordinatnega sistema konstrukcije. Upostevan je desnosucni
%   koordinatni sistem.
%
% - SteviloPolj: Spremenljivka je skalar. Njena vrednost pomeni stevilo polj
%   pripadajocega okvirja.
%
% - SteviloEtaz: Spremenljivka je skalar. Njena vrednost pomeni etazo objekta, 
%   do katere sega pripadajoci makroelement.
%    
% - DolzinaPolj: Spremenljivka je vektor. Vrednosti posameznih komponent
%   pomenijo dolzine pripadajocih polj okvirja.
%
% - Ast: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   ploscine prerezov stebrov v pripadajoci vrsti.
%
% - Ist: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   vztrajnostne momente prerezov pripadajocih stebrov okoli osi "z".
%
% - Apr: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   ploscine prerezov preck v pripadajocem polju. 
%  
% - Ipr: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   vztrajnostne momente prerezov pripadajocih preck okoli osi "z".
%
% - OdstranjeniElementi: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo elemente, ki se odstranijo iz osnovno definiranega 
%   okvirja.
%
%IZHODNI PODATKI: 
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Ko: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v globalnem koordinatnem sistemu. 
%     
% - Kl: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v lokalnem koordinatnem sistemu. 

% - Km: Spremenljivka pomeni togostno matriko makroelementa v lokalnem 
%   koordinatnem sistemu.  
% 
% - To: Spremenljivka pomeni transformacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)   
%
% - Tr: Spremenljivka pomeni rotacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)
%  
% - PreslikavaElementa: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo zaporedne stevilke elementov, ki sestavljajo 
%   makroelement.
%
% - PreslikavaVozlisca: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo zaporedne stevilke vozlisc, ki sestavljajo 
%   makroelement.
%
% - ozm: Spremenljivka je skalar. Njena vrednost predstavlja vrsto
%   makroelementa, ki ga oznacuje.
%
% - stp: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   stevilo polj okvirja v posamezni etazi.
%
% - ste: Spremenljivka je skalar. Njena vrednost predstavlja stevilo
%   elementov, ki sestavljajo pripadajoci makroelement

%definicija globalnih spremenljivk
global E
global G
global H
global N
global L
global To
global Tr
global Kl
global Ko
global m
global n
global ste
global Km
global ozm
global stp
global Ac
global Acsy
global Icz
global Ab
global Absy
global Ibz
global ds
global ts
global X
global Y
global Xel
global Yel
global Xelf
global Yelf
global esx
global esy
global lp
global alfa
global PreslikavaElementa
global PreslikavaVozlisca
global PreslikavaVozlisca2
global PodatkiOKonstrukciji
global RezultatiAnalize

el=length(X)+1;
N=PodatkiOKonstrukciji.GlobalniPodatki.SteviloEtaz;
H=PodatkiOKonstrukciji.GlobalniPodatki.VisineEtaz;
E=PodatkiOKonstrukciji.GlobalniPodatki.ElasticniModul;
v=PodatkiOKonstrukciji.GlobalniPodatki.PoissonovKolicnik;
G=E/(2*(1+v));
ozm(el)=1;
X(el)=PodatkiOKonstrukciji.Makroelement(el).Pozicija(1);
Y(el)=PodatkiOKonstrukciji.Makroelement(el).Pozicija(2);
m(el)=PodatkiOKonstrukciji.Makroelement(el).SteviloPolj;
n(el)=PodatkiOKonstrukciji.Makroelement(el).SteviloEtaz;
ode=PodatkiOKonstrukciji.Makroelement(el).OdstranjeniElementi;
alfa(el)=PodatkiOKonstrukciji.Makroelement(el).Orientiranost;

ds(:,el)=0;
ts(el)=0;

%Ustvarjanje seznama podatkov
for i=1:(m(el)+1)
    Ac(el,i)=PodatkiOKonstrukciji.Makroelement(el).StebriA(i);
    Icz(el,i)=PodatkiOKonstrukciji.Makroelement(el).StebriIz(i);
    Acsy(el,i)=PodatkiOKonstrukciji.Makroelement(el).StebriAs(i);
end
for i=1:m(el)
    Ab(el,i)=1000*PodatkiOKonstrukciji.Makroelement(el).GredeA(i);
    Ibz(el,i)=PodatkiOKonstrukciji.Makroelement(el).GredeIz(i);
    Absy(el,i)=PodatkiOKonstrukciji.Makroelement(el).GredeAs(i);
    L(el,i)=PodatkiOKonstrukciji.Makroelement(el).DolzinaPolj(i);
end

%Generiranje togostne matrike stebrov "C"
C=zeros((m(el)+1)*(n(el)+1)*3);
for j=1:n(el)
    for i=(m(el)*(j-1)+j):((m(el)+1)*j)%za vse stebre
        %kontrola ali je i-ti steber odstranjen
        indeks=0;
        for k=1:length(ode)
            if ode(k)==i
                indeks=indeks+1;
            end
        end
        %racun lokalne togostne matrike i-tega stebra 
        if indeks==1
            c=zeros(6);
        else 
            fiy=12*E*Icz(el,i-(j-1)*(m(el)+1))/(G*Acsy(el,i-(j-1)*(m(el)+1))*H(j)^2);
            a=E*Ac(el,i-(j-1)*(m(el)+1))/H(j);
            by=12*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)^3*(1+fiy));
            cy=6*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)^2*(1+fiy));
            dy=(4+fiy)*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)*(1+fiy));
            ey=(2-fiy)*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)*(1+fiy));
            c=[by  cy  0  -by  cy  0;...
               cy  dy  0  -cy  ey  0;...
               0   0   a   0   0  -a;...
              -by -cy  0   by -cy  0;...
               cy  ey  0  -cy  dy  0;...
               0   0  -a   0   0   a];
        end
        %generiranje togostne matrike stebrov okvirja
        C([((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 (i-1)*3+(m(el)+1)*3+1 (i-1)*3+(m(el)+1)*3+2 (i-1)*3+(m(el)+1)*3+3],...
          [((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 ((i-1)*3)+(m(el)+1)*3+1 ((i-1)*3)+(m(el)+1)*3+2 ((i-1)*3)+(m(el)+1)*3+3])=...
        C([((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 (i-1)*3+(m(el)+1)*3+1 (i-1)*3+(m(el)+1)*3+2 (i-1)*3+(m(el)+1)*3+3],...
          [((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 ((i-1)*3)+(m(el)+1)*3+1 ((i-1)*3)+(m(el)+1)*3+2 ((i-1)*3)+(m(el)+1)*3+3])+c;
    end
end

%Generiranje togostne matrike preck "B"
B=zeros((m(el)+1)*(n(el)+1)*3);
for i=1:n(el)
    for j=((m(el)+1)*n(el))+(i-1)*m(el)+1:((m(el)+1)*n(el))+m(el)*i%za vse precke
        %kontrola ali je pripadajoca precka odstranjena
        indeks=0;
        for k=1:length(ode)
            if ode(k)==j
                indeks=indeks+1;
            end
        end
        %racun lokalne togostne matrike j-tega elementa - 
        %pomeni precko "j-stevilo stebrov"
        if indeks==1
            b=zeros(6);
        else
            fiy=12*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(G*Absy(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^2);
            a=E*Ab(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/L(el,j-(i-1)*m(el)-(m(el)+1)*n(el));
            by=12*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^3*(1+fiy));
            cy=6*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^2*(1+fiy));
            dy=(4+fiy)*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*(1+fiy));
            ey=(2-fiy)*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*(1+fiy));
            b=[a   0    0   -a    0   0;...
               0   dy  -cy   0    ey  cy;...
               0  -cy   by   0   -cy -by;...
              -a   0    0    a    0   0;...
               0   ey  -cy   0    dy  cy;...
               0   cy  -by   0    cy  by];
        end
        %generiranje togostne matrike preck okvirja
        B([(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6],...
          [(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6])=...
        B([(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6],...
          [(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6])+b;
    end
end

%Tvorjenje togostne matrike okvirja
Knepodprto=C+B;

%Iskanje nicelnih oz. nenicelnih komponent na diagonali tog. matrike 
for i=1:(m(el)+1)*(n(el)+1)*3
    if Knepodprto(i,i)>0
        IndikatorProstostnihStopenj(i)=1;
    else
        IndikatorProstostnihStopenj(i)=0;
    end
end

%Upostevanje podprtih in odstranjenih vozlisc
for i=1:(m(el)+1)*(n(el)+1)*3
    if i<=(m(el)+1)*3
         UpostevaneProstostneStopnje(i)=0;
    else 
         UpostevaneProstostneStopnje(i)=IndikatorProstostnihStopenj(i);
    end
end

%Tvorjenje togostne matrike podprtega makroelementa (deformabilna ploa v
%svoji ravnini)
indeks=find(UpostevaneProstostneStopnje==1);
for i=1:sum(UpostevaneProstostneStopnje)
    for j=1:sum(UpostevaneProstostneStopnje)
        Km(i,j,el)=Knepodprto(indeks(i),indeks(j));
    end
end

%Razdelitev na bistvene in nebistvene prostostne stopnje
Knn=Km(1:length(indeks),1:length(indeks),el);
Knn(:,1:3:length(indeks)-2)=[];
Knn(1:3:length(indeks)-2,:)=[];

Knb=Km(1:length(indeks),1:length(indeks),el);
Knb(:,3:3:length(indeks))=[];
Knb(:,2:2:2*length(indeks)/3)=[];
Knb(1:3:length(indeks)-2,:)=[]; 

Kbn=Km(1:length(indeks),1:length(indeks),el);
Kbn(:,1:3:length(indeks)-2)=[];
Kbn(3:3:length(indeks),:)=[];
Kbn(2:2:2*length(indeks)/3,:)=[];

Kbb=Km([1:3:length(indeks)-2],[1:3:length(indeks)-2],el);

%Generiranje kondenzirane togostne matrike okvirja
Kc=Kbb-Kbn*inv(Knn)*Knb;

%Priprava matrike za doloevanje kondenzirane togostne matrike z
%upotevanjem enakosti etanih pomikov.Pomeni, da upostevamo tudi nicelne
%vrstice. Tako lahko uporabimo algoritem za tvorjenje matrike Klc, ki je ze
%spisan za okvir brez odstranjenih elementov.
NenicelneVrstice=find(IndikatorProstostnihStopenj((m(el)+1)*3+1:(m(el)+1)*(n(el)+1)*3));
NenicelneVrstice=NenicelneVrstice(3:3:length(NenicelneVrstice))./3;
Kc2=zeros((m(el)+1)*n(el));
for i=1:length(NenicelneVrstice)
    for j=1:length(NenicelneVrstice)
        Kc2(NenicelneVrstice(i),NenicelneVrstice(j))=Kc2(NenicelneVrstice(i),NenicelneVrstice(j))+Kc(i,j);
    end
end

%Tvorjenje kondenzirane togostne matrike okvirja v lokalnem koordinatenm 
%sistemu. Upostevane so po tri prostostne stopnje v posamezni etazi: 
%dve translaciji v ravnini plosce in rotacija okoli navpicne osi.
Kl(:,:,el)=zeros(3*N);
for i=1:n(el)
    for j=1:n(el)
        for k=1:(m(el)+1)
            d=Kc2([(i-1)*(m(el)+1)+1:(m(el)+1)*i],(j-1)*(m(el)+1)+k);
            Kl(i,j,el)= Kl(i,j,el)+sum(d);
        end
    end
end

RezultatiAnalize.Matrike.Makroelement(el).TogostnaMatrika=Kl([1:n(el)],[1:n(el)],el);
RezultatiAnalize.Matrike.Makroelement(el).PodajnostnaMatrika=inv(Kl([1:n(el)],[1:n(el)],el));

if alfa(el)==90
    s=1;
    c=0;
elseif alfa(el)==270
    s=-1;
    c=0;
else
    s=sin(alfa(el)*pi/180);
    c=cos(alfa(el)*pi/180);
end

%Generiranje transformacijskih matrik
To(:,:,el)=[eye(N)    zeros(N) -Y(el)*eye(N);...
            zeros(N)  eye(N)    X(el)*eye(N);...
            zeros(N)  zeros(N)  eye(N) ];
        
Tr(:,:,el)=[c*eye(N)  s*eye(N)  zeros(N);...
           -s*eye(N)  c*eye(N)  zeros(N);...
            zeros(N)  zeros(N)  eye(N) ];
       
%Generiranje kondenzirane togostne matrike okvirja v globalnem koordinatenem sistemu.            
Ko(:,:,el)=(To(:,:,el))'*((Tr(:,:,el))'*Kl(:,:,el)*Tr(:,:,el))*To(:,:,el);

%Preslikave elementov
if isempty(ode)==1
    ElementFiktivni=[1:(m(el)+1)*n(el)+m(el)*n(el)]; %vsi elementi
    for i=1:((m(el)+1)*n(el)+m(el)*n(el)) %vsi elementi
        PreslikavaElementa(i,el)=i;
    end
else
    UpostevaniElementi=diag(ones((m(el)+1)*n(el)+m(el)*n(el)));
    UpostevaniElementi([ode])=0;
    ElementFiktivni=find(UpostevaniElementi);
    for i=1:length(ElementFiktivni)   
        PreslikavaElementa(i,el)=ElementFiktivni(i);
    end
end

%Preslikave vozlisc
VozlisceFiktivno=find(IndikatorProstostnihStopenj(3:3:(m(el)+1)*(n(el)+1)*3));
for i=1:length(VozlisceFiktivno)
    PreslikavaVozlisca(i,el)=VozlisceFiktivno(i);
    PreslikavaVozlisca2(VozlisceFiktivno(i),el)=i;
end

%Tvorjenje vektorja stevila polj "stp"
IndikatorElementa([ElementFiktivni],el)=1;
for i=1:n(el)
    stp(i,el)=sum(IndikatorElementa([((i-1)*(m(el)+1)+1):((i-1)*(m(el)+1)+(m(el)+1))],el))-1;
end

%Racun stevila elementov okvirja
ste(el)=length(find(PreslikavaElementa(:,el)));

%Racun koordinat vozlisc stebrov (TUKAJ JE NAPAKA, E GRE ZA ENO ETAO!!!)
stsf(el)=(m(el)+1)*(n(el)); %stevilo fiktivnih stebrov
stef(el)=(m(el)+1)*(n(el))+m(el)*n(el);
for i=1:m(el)+1
    if i==1
       Xelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],1,el)=diag(zeros(n(el)));  %zacetno vozlisce
       Yelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],1,el)=[0 cumsum(H(1:(n(el)-1)))'];
       Xelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],2,el)=diag(zeros(n(el))); %koncno vozlisce
       Yelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],2,el)=[cumsum(H)]';
    else
       Xelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],1,el)=diag(eye(n(el)).*sum(L(el,1:i-1)))';  %zacetno vozlisce
       Yelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],1,el)=[0 cumsum(H(1:(n(el)-1)))'];
       Xelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],2,el)=diag(eye(n(el)).*sum(L(el,1:i-1)))'; %koncno vozlisce
       Yelf([i:(m(el)+1):(n(el)-1)*(m(el)+1)+i],2,el)=[cumsum(H)];
    end    
end

%Racun koordinat vozlisc preck
for i=1:m(el)
    if i==1
        Xelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],1,el)=diag(zeros(n(el)));
        Yelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],1,el)=cumsum(H);
        Xelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],2,el)=diag(eye(n(el)).*L(el,1));
        Yelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],2,el)=cumsum(H);
    else
        Xelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],1,el)=diag(eye(n(el)).*sum(L(el,1:i-1)));
        Yelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],1,el)=cumsum(H);
        Xelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],2,el)=diag(eye(n(el)).*sum(L(el,1:i)));
        Yelf([stsf(el)+i:m(el):stef(el)-(m(el)-i)],2,el)=cumsum(H);       
    end    
end

%Racun koordinat vozlisc
for i=1:ste(el)
    Xel(i,:,el)=Xelf(ElementFiktivni(i),:,el);
    Yel(i,:,el)=Yelf(ElementFiktivni(i),:,el);
end

%Tvorjenje smernih vektorjev
for i=1:ste(el)
    if PreslikavaElementa(i,el)<=(m(el)+1)*n(el)
        esx(i,[1 2],el)=[0 1];
        esy(i,[1 2],el)=[-1 0];
    else
        esx(i,[1 2],el)=[1 0];
        esy(i,[1 2],el)=[0 1];
    end
end

%tvorjenje razdalj od zacetnih vozlisc l
for i=1:ste(el)
    if PreslikavaElementa(i,el)<=(m(el)+1)*n(el)
        etaza=ceil(PreslikavaElementa(i,el)/(m(el)+1));
        lp(i,[1:11],el)=[0:0.1:1].*H(etaza);
    else
        etaza=ceil((PreslikavaElementa(i,el)-(m(el)+1)*n(el))/(m(el)));
        polje=(PreslikavaElementa(i,el)-(m(el)+1)*n(el))-(etaza-1)*m(el);
        lp(i,[1:11],el)=[0:0.1:1].*L(el,polje);
    end
end