function [Ko,Kl,Km,To,Tr,n,Ac,Acsy,Icz,Aw,Awsy,Iwz,L,ozm,ste,X,Y]=StenaNaStebrih(MakroElement,koordinataX,koordinataY,Orientiranost,SirinaStebrov,SirinaOdprtine,DebelinaStene,SteviloEtaz,SirinaStene)
%DEFINICIJA:
%
%   Funkcija "StenaNaStebrih" vrne togostne in transformacijske matrike 
%   stene  na stebrih in podatke o geometriji. Vsi izhodni podatki so 
%   globalne spremenljivke.
%
%VHODNI PODATKI:
%
% - MakroElement: Spremenljivka je skalar. Njena vrednost pomeni zaporedno 
%   tevilko makroelementa, ki ga podajamo v program.
%
% - koordinataX: Spremenljivka je skalar. Njena vrednost pomeni x-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%  
% - koordinataY: Spremenljivka je skalar. Njena vrednost pomeni y-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%
% - alfa: Spremenljivka je skalar. Njena vrednost pomeni kot med osjo 1
%   lokalnega koordinatnega sistema vozlisc makroelementa in osjo "X" globalnega
%   koordinatnega sistema konstrukcije. Upostevan je desnosucni
%   koordinatni sistem.
%
% - SteviloEtaz: Spremenljivka je skalar. Njena vrednost pomeni etazo objekta, 
%   do katere sega pripadajoci makroelement.
%    
% - DolzinaPolj: Spremenljivka je vektor dolzine dva. Komponente vektorja predstavljajo
%   dolzine pripadajocih polj stene na stebrih.
%
% - Ast: Spremenljivka je vektor. Vrednost posameznih komponent Ast predstavljajo
%   ploscine prerezov  stebrov v pripadajoci vrsti.
%
% - Ist: Spremenljivka je vektor. Vrednost posameznih komponent Ist predstavljajo
%   vztrajnostne momente prerezov stebrov okoli osi "z" v pripadajoci vrsti 
%
% - As: Spremenljivka je vektor. Vrednost posameznih komponent As predstavljajo
%   ploscine prerezov sten v pripadajoci etazi. 
%  
% - Is: Spremenljivka je vektor. Vrednost posameznih komponent Is predstavljajo
%   vztrajnostne momente prerezov sten okoli osi "z" v pripadajoci etazi.
%
%IZHODNI PODATKI:
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Ko: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v globalnem koordinatnem sistemu.
%    
% - Kl: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v lokalnem koordinatnem sistemu.  
%
% - Km: Spremenljivka pomeni togostno matriko makroelementa v lokalnem 
%   koordinatnem sistemu.  
% 
% - To: Spremenljivka pomeni transformacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)   
%
% - Tr: Spremenljivka pomeni rotacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)
%
% - ozm: Spremenljivka je skalar. Njena vrednost predstavlja vrsto
%   makroelementa, ki ga oznacuje.
%
% - ste: Spremenljivka je skalar. Njena vrednost predstavlja stevilo
%   elementov, ki sestavljajo pripadajoci makroelement

%definicija globalnih spremenljivk
global E
global G
global v
global H
global N
global L
global stm
global ste
global m
global n
global ozm
global Km
global Kl
global To
global Tr
global Ko
global Ac
global Acsy
global Icz
global Aw
global Awsy
global Iwz
global X
global Y
global alfa

el=MakroElement;
ozm(el)=3;
X(el)=koordinataX;
Y(el)=koordinataZ;
n(el)=SteviloEtaz;
ste(el)=4+(n(el)-1);
alfa(el)=Orientiranost;

%Ustvarjanje seznamov podatkov
for i=1:2
    Ac(el,i)=SirinaStebrov(i)*DebelinaStene;
    Acsy(el,i)=Ac(el,i)/1.2;
    Icz(el,i)=DebelinaStene*DimezijaStebrov(i)^3/12;  
end
L(el,1)=(DimenzijaOdprtine+DimenzijaStebrov(2))/2;
L(el,2)=(DimenzijaOdprtine+DimenzijaStebrov(1))/2;
for i=2:n(el)
    if length(SirinaStene)==1
        Aw(el,i)=SirinaStene*DebelinaStene;
        Awsy(el,i)=Aw(el,i)/1.2;
        Iwz(el,i)=SirinaStene^3*DebelinaStene/12;
    else
        Aw(el,i)=SirinaStene(i-1)*DebelinaStene;
        Awsy(el,i)=Aw(i)/1.2;
        Iwz(el,i)=SirinaStene(i-1)^3*DebelinaStene/12;
    end
end

%Generiranje togostne matrike stebrov "C"
C=zeros(15+(n(el)-1)*3);
for i=1:2%za oba stebra      
    fiy=12*E*Icz(el,i)/(G*Acsy(el,i)*H(1)^2);
    a=E*Ac(el,i)/H(1);
    by=12*E*Icz(el,i)/(H(1)^3*(1+fiy));
    cy=6*E*Icz(el,i)/(H(1)^2*(1+fiy));
    dy=(4+fiy)*E*Icz(el,i)/(H(1)*(1+fiy));
    ey=(2-fiy)*E*Icz(el,i)/(H(1)*(1+fiy));
    c=[by   cy   0   -by   cy   0;...
       cy   dy   0   -cy   ey   0;...
       0    0    a    0    0   -a;...
      -by  -cy   0    by  -cy   0;...
       cy   ey   0   -cy   dy   0;...
       0    0   -a    0    0    a];
    C([(i-1)*3+1:(i-1)*3+3 (i-1)*3+7:(i-1)*3+9],[(i-1)*3+1:(i-1)*3+3 (i-1)*3+7:(i-1)*3+9])=C([(i-1)*3+1:(i-1)*3+3 (i-1)*3+7:(i-1)*3+9],[(i-1)*3+1:(i-1)*3+3 (i-1)*3+7:(i-1)*3+9])+c;
end

%Generiranje togstne matrike stene "W"
W=zeros(15+(n(el)-1)*3);
for i=2:n(el)%za vse stene v zgornjih etazah
    fiy=12*E*Iwz(el,i)/(G*Awsy(el,i)*H(i)^2);
    a=E*Aw(el,i)/H(i);
    by=12*E*Iwz(el,i)/(H(i)^3*(1+fiy));
    cy=6*E*Iwz(el,i)/(H(i)^2*(1+fiy));
    dy=(4+fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    ey=(2-fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    w=[by   cy   0   -by   cy   0;...
       cy   dy   0   -cy   ey   0;...
       0    0    a    0    0   -a;...
      -by  -cy   0    by  -cy   0;...
       cy   ey   0   -cy   dy   0;...
       0    0   -a    0    0    a];
    W([13+(i-2)*3:18+(i-2)*3],[13+(i-2)*3:18+(i-2)*3])=W([13+(i-2)*3:18+(i-2)*3],[13+(i-2)*3:18+(i-2)*3])+w;
end

%Generiranje togostne matrike togih preck "B"
B=zeros(15+(n(el)-1)*3);
A=100*Aw(el,2); %povrina prereza toge preke
I=100*Iwz(el,2); %vztrajnostni moment prereza toge preke
b=[E*A/L(el,1) 0 0 -E*A/L(el,1) 0 0;... 
   0 12*E*I/L(el,1)^3 6*E*I/L(el,1)^2 0 -12*E*I/L(el,1)^3 6*E*I/L(el,1)^2;...
   0 6*E*I/L(el,1)^2 4*E*I/L(el,1) 0 -6*E*I/L(el,1)^2 2*E*I/L(el,1);... 
  -E*A/L(el,1) 0 0 E*A/L(el,1) 0 0;... 
   0 -12*E*I/L(el,1)^3 -6*E*I/L(el,1)^2 0 12*E*I/L(el,1)^3 -6*E*I/L(el,1)^2;... 
   0 6*E*I/L(el,1)^2 2*E*I/L(el,1) 0 -6*E*I/L(el,1)^2 4*E*I/L(el,1)];
B([7:9 13:15],[7:9 13:15])=B([7:9 13:15],[7:9 13:15])+b;

b=[E*A/L(el,2) 0 0 -E*A/L(el,2) 0 0;... 
   0 12*E*I/L(el,2)^3 6*E*I/L(el,2)^2 0 -12*E*I/L(el,2)^3 6*E*I/L(el,2)^2;...
   0 6*E*I/L(el,2)^2 4*E*I/L(el,2) 0 -6*E*I/L(el,2)^2 2*E*I/L(el,2);... 
  -E*A/L(el,2) 0 0 E*A/L(el,2) 0 0;... 
   0 -12*E*I/L(el,2)^3 -6*E*I/L(el,2)^2 0 12*E*I/L(el,2)^3 -6*E*I/L(el,2)^2;... 
   0 6*E*I/L(el,2)^2 2*E*I/L(el,2) 0 -6*E*I/L(el,2)^2 4*E*I/L(el,2)];
B([13:15 10:12],[13:15 10:12])=B([13:15 10:12],[13:15 10:12])+b;

%Tvorjenje togostne matrike podprtega makroelementa
                           
Km(:,:,el)=C(7:end,7:end)+B(7:end,7:end)+W(7:end,7:end);

%Razdelitev na bistvene in nebistvene prostostne stopnje
Knn=Km(:,:,el);
Knn(:,1:3:end-2)=[];
Knn(1:3:end-2,:)=[];

Knb=Km(:,:,el);
Knb(:,3:3:end)=[];
Knb(:,2:2:end)=[];
Knb(1:3:end-2,:)=[];

Kbn=Km(:,:,el);
Kbn(3:3:end,:)=[];
Kbn(2:2:end,:)=[];
Kbn(:,1:3:end-2)=[];

Kbb=Km([1:3:end-2],[1:3:end-2],el);

%Generiranje kondenzirane togostne matrike stene na stebrih
Kc=Kbb-Kbn*inv(Knn)*Knb;

%Tvorjenje kondenzirane togostne matrike makroelementa v lokalnem
%koordinatnem sistemu. Upostevane so po tri prostostne stopnje
%v posamezni etazi: dve translaciji v ravnini plosce in rotacija okoli
%navpicne osi.
Kl(:,:,el)=zeros(3*N);
for i=1:n(el)
    for j=1:n(el)
        if i<=1 
            if j<=1
                for k=1:3
                    a=Kc([1:3],k);
                    Kl(i,j,el)=Kl(i,j,el)+sum(a);
                end
            else
                Kl(i,j,el)=sum(Kc([1:3],2+j));
            end
        else
            if j<=1
                Kl(i,j,el)=sum(Kc(2+i,[1:3]));
            else
                Kl(i,j,el)=Kc(i+2,j+2);
            end
        end
    end
end
    
if alfa(el)==90
    s=1;
    c=0;
elseif alfa(el)==270
    s=-1;
    c=0;
else
    s=sin(alfa(el)*pi/180);
    c=cos(alfa(el)*pi/180);
end

%Generiranje transformacijskih matrik
Tr(:,:,el)=[c*eye(N)  s*eye(N) zeros(N);...
           -s*eye(N)  c*eye(N) zeros(N);...
            zeros(N)  zeros(N) eye(N)];

To(:,:,el)=[eye(N)    zeros(N) -Y(el)*eye(N);...
            zeros(N)  eye(N)    X(el)*eye(N);...
            zeros(N)  zeros(N)  eye(N)];

%Tvorjenje kondenzirane togostne matrike stene na stebrih v globalnem koordinatenem sistemu.
Ko(:,:,el)=(To(:,:,el))'*((Tr(:,:,el))'*Kl(:,:,el)*Tr(:,:,el))*To(:,:,el);





      