% funkcija axesg ustvari sliko v kateri je vec koordinatnih sistemov za risanje diagramov v eni sliki
% Matjaz Dolsek, 19.3.2004
%
% [slika,ks,Lx,Ly]=axesg(nSlikX,Xs,xRobL,xSredina,xRobD,nSlikY,Ys,yRobS,ySredina,yRobZ,PozX,PozY)
%
% SLO:
%
% VHODNI PARAMETRI
% nSlikX, nSlikY = stevilo diagramov v X in Y smeri 
% Xs,Ys = velikost celotne slike (cm) v X in Y smeri
% xRobL,xRobD,xSredina = razdalja v prve slike od levega roba, vmesna razdalja v X smeri in razdalja zadnje slike od desnega roba
% yRobS,yRobZ,ySredina = razdalja v prve slike od spodnjega roba, vmesna razdalja v Y smeri in razdalja zadnje slike od zgornjega roba
% PozX, PozY = pozicija spodnjega levega roba na ekranu
% IZHODNI PARAMETRI
% slika.....kazalec na sliko
% ks(i,j)...kazalci na koordinatne sisteme, i-ti ks v X smeri, j-ti ks v Y smeri
% Lx, Ly....velikost slike v X in Y smeri
%
% ENG:
%
% INPUT PARAMETERS
% nSlikX, nSlikY = number of axes in X and Y direction 
% Xs,Ys = size of the figure (cm) in X and Y direction
% xRobL,xRobD,xSredina = distance (cm) of the first axes from the left edge of
% the figure, between figures, and from the last axes to the right edge of
% the figure, all in X direction.
% yRobS,yRobZ,ySredina = distance between the first axes and bottom edge,
% between axes and distance from the top axes and top edge of the figure in
% Y direction
% PozX, PozY = pozition of the left bottom edge of the figure as appear on
% the screen
% OUTPUT PARAMETERS
% slika.....pointer to the figure
% ks(i,j)...pointer on the axes, i-th ks in X direction, j-th ks in Y direction
% Lx, Ly....size (cm) of the axes in X and Y direction

function [slika,ks,Lx,Ly]=axesg(nSlikX,Xs,xRobL,xSredina,xRobD,nSlikY,Ys,yRobS,ySredina,yRobZ,PozX,PozY,RV)

Lx(1)=(Xs-xRobL-xSredina-xRobD)*(RV/(RV+1));
Lx(2)=(Xs-xRobL-xSredina-xRobD)*(1/(RV+1));
Ly=(Ys-yRobS-(nSlikY-1)*ySredina-yRobZ)/nSlikY;
slika=figure('Units','centimeters','Position',[PozX PozY Xs Ys],'PaperType','A4');

for i=1:nSlikX
    for j=1:nSlikY
        if i==1
           ks(i,j)=axes('position',[(xRobL)/Xs (yRobS+(j-1)*(ySredina+Ly))/Ys Lx(i)/Xs Ly/Ys],'Box','on','Units','normalized');
        else
           ks(i,j)=axes('position',[(xRobL+(i-1)*(xSredina+Lx(i-1)))/Xs (yRobS+(j-1)*(ySredina+Ly))/Ys Lx(i)/Xs Ly/Ys],'Box','on','Units','normalized');
        end
    end
end