function IzracunajJedro
%DEFINICIJA:
%
%   Funkcija "Jedro" vrne togostne in transformacijske matrike jedra in 
%   podatke o geometriji. Vsi izhodni podatki so globalne spremenljivke. 
%
%VHODNI PODATKI:
%
% - MakroElement: Spremenljivka je skalar. Njena vrednost pomeni zaporedno 
%   tevilko makroelementa, ki ga podajamo v program.
%
% - koordinataX: Spremenljivka je skalar. Njena vrednost pomeni x-koordinato
%   centra togosti stene v globalnem koordinatenem sistemu konstrukcije.
%  
% - koordinataY: Spremenljivka je skalar. Njena vrednost pomeni y-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%
% - alfa: Spremenljivka je skalar. Njena vrednost pomeni kot med osjo 1
%   lokalnega koordinatnega sistema vozlisc makroelementa in osjo "X" globalnega
%   koordinatnega sistema konstrukcije. Upostevan je desnosucni
%   koordinatni sistem.
%
% - SteviloEtaz: Spremenljivka je skalar. Njena vrednost pomeni etazo objekta, 
%   do katere sega pripadajoci makroelement.
%
% - Asy: Spremenljivka je vektor. Posamezne komponente pomenijo strizne prereze
%   jedra v pripadajoci etazi in sicer v smeri osi "y" lokalnega k. sistema.
%
% - Asz: Spremenljivka je vektor. Posamezne komponente pomenijo strizne prereze
%   jedra v pripadajoci etazi in sicer v smeri osi "z" lokalnega k. sistema.
%
% - Iy: Spremenljivka je vektor. Posamezne komponente pomenijo vztrajnostne
%   momente prereza jedra v pripadajoci etazi in sicer okrog osi "y" lokalnega k.
%   sistema.
%
% - Iz: Spremenljivka je vektor. Posamezne komponente pomenijo vztrajnostne
%   momente prereza jedra v pripadajoci etazi in sicer okrog osi "z" lokalnega k.
%   sistema.
%
% - It: Spremenljivka je vektor. Posamezne komponente pomenijo torzijske 
%   vztrajnostne momente prereza jedra v pripadajoci etazi.
%
%IZHODNI PODATKI:
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Ko: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v globalnem koordinatnem sistemu.
%    
% - Kl: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v lokalnem koordinatnem sistemu.  
%
% - Km: Spremenljivka pomeni togostno matriko makroelementa v lokalnem 
%   koordinatnem sistemu.  
% 
% - To: Spremenljivka pomeni transformacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)   
%
% - Tr: Spremenljivka pomeni rotacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)
%
% - ozm: Spremenljivka je skalar. Njena vrednost pomeni vrsto
%   makroelementa, ki ga oznacuje.
%
% - ste: Spremenljivka je skalar. Njena vrednost pomeni stevilo
%   elementov, ki sestavljajo pripadajoci makroelement
%
% - sts: Spremenljivka je skalar. Njena vrednost pomeni stevilo
%   prostostnih stopenj jedra, ki se upostevajo v dinamicni analizi.
%
% - tor: Spremenljivka je skalar. Njena vrednost oznacuje torzijsko
%   odpornost jedra.

%definicija globalnih spremenljivk
global N
global H
global E
global G
global n
global Km
global To
global Tr
global Kl
global Ko
global Awsy
global Awsz
global Iwy
global Iwz
global Iwt
global ste
global ozm
global sts
global tor
global X
global Y
global Xel
global Yel
global esx
global esy
global lp
global alfa



el=MakroElement;
ozm(el)=5;
X(el)=KoordinataX;
Y(el)=KoordinataY;
n(el)=SteviloEtaz;
ste(el)=n(el);
alfa(el)=Orientiranost;

if length(find(It))==0
    sts(el)=2;
    tor(el)=0;
else
    sts(el)=3;
    tor(el)=1;
end

%Ustvarjanje seznamov podatkov
for i=1:n(el)
    if length(Asy)==1
        Awsy(el,i)=Asy;
        Iwy(el,i)=Iy;
    else
        Awsy(el,i)=Asy(i);
        Iwy(el,i)=Iy(i);
    end
end

for i=1:n(el)
    if length(Asz)==1
        Awsz(el,i)=Asz;
        Iwz(el,i)=Iz;
    else
        Awsz(el,i)=Asz(i);
        Iwz(el,i)=Iz(i);
    end
end
        
for i=1:n(el)
    if length(It)==1
        Iwt(el,i)=It;
    else
        Iwt(el,i)=It(i);
    end
end

%Generiranje togostne matrike jedra
W=zeros((n(el)+1)*5); 
for i=1:n(el)
    t=G*Iwt(el,i)/H(i);
    if Awsy(el,i)>0
        fiy=12*E*Iwz(el,i)/(G*Awsy(el,i)*H(i)^2);
    else
        fiy=0;
    end
    if Awsz(el,i)>0
        fiz=12*E*Iwy(el,i)/(G*Awsz(el,i)*H(i)^2);
    else
        fiz=0;
    end
    by=12*E*Iwz(el,i)/(H(i)^3*(1+fiy));
    bz=12*E*Iwy(el,i)/(H(i)^3*(1+fiz));
    cy=6*E*Iwz(el,i)/(H(i)^2*(1+fiy));
    cz=6*E*Iwy(el,i)/(H(i)^2*(1+fiz));
    dy=(4+fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    dz=(4+fiz)*E*Iwy(el,i)/(H(i)*(1+fiz));
    ey=(2-fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    ez=(2-fiz)*E*Iwy(el,i)/(H(i)*(1+fiz));
    w=[by  0   0   cy  0  -by  0   0   cy  0;...
       0   bz -cz  0   0   0  -bz -cz  0   0;...
       0  -cz  dz  0   0   0   cz  ez  0   0;...
       cy  0   0   dy  0  -cy  0   0   ey  0;...
       0   0   0   0   t   0   0   0   0  -t;...
      -by  0   0  -cy  0   by  0   0  -cy  0;...
       0  -bz  cz  0   0   0   bz  cz  0   0;...
       0  -cz  ez  0   0   0   cz  dz  0   0;...
       cy  0   0   ey  0  -cy  0   0   dy  0;...
       0   0   0   0   t   0   0   0   0  -t];
    W([(i-1)*5+1:(i-1)*5+10],[(i-1)*5+1:(i-1)*5+10])=W([(i-1)*5+1:(i-1)*5+10],[(i-1)*5+1:(i-1)*5+10])+w;   
end

%Tvorjenje togostne matrike jedra
Knepodprto=W;

%Iskanje nicelnih oz. nenicelnih komponent na diagonali togostne matrike 
for i=1:(n(el)+1)*5
    if Knepodprto(i,i)>0
        IndikatorProstostnihStopenj(i)=1;
    else
        IndikatorProstostnihStopenj(i)=0;
    end
end

%Upostevanje podprtih in odstranjenih vozlisc
for i=1:(n(el)+1)*5
    if i<=5
         UpostevaneProstostneStopnje(i)=0;
    else 
         UpostevaneProstostneStopnje(i)=IndikatorProstostnihStopenj(i);
    end
end

%Tvorjenje togostne matrike podprtega makroelementa
indeks=find(UpostevaneProstostneStopnje==1);
for i=1:sum(UpostevaneProstostneStopnje)
    for j=1:sum(UpostevaneProstostneStopnje)
        Km(i,j,el)=Knepodprto(indeks(i),indeks(j));
    end
end

%Razdelitev na bistvene in nebistvene prostostne stopnje
if tor(el)==1
    indeksKbb=[[1:5:n(el)*5-4] [2:5:n(el)*5-3] [5:5:n(el)*5]];
    indeksKnn=[[3:5:n(el)*5-2] [4:5:n(el)*5-1]];
    Knn=Km(:,:,el);
    Knb=Km(:,:,el);
    Kbn=Km(:,:,el);
    Kbb=Km(:,:,el);
else
    indeksKbb=[[1:4:n(el)*4-3] [2:4:n(el)*4-2]];
    indeksKnn=[[3:4:n(el)*4-1] [4:4:n(el)*4]];
    Knn=Km(:,:,el);
    Knb=Km(:,:,el);
    Kbn=Km(:,:,el);
    Kbb=Km(:,:,el);
end

Knn(:,[indeksKbb])=[];
Knn([indeksKbb],:)=[];

Knb(:,[indeksKnn])=[];
Knb([indeksKbb],:)=[];

Kbn(:,[indeksKbb])=[];
Kbn([indeksKnn],:)=[];

Kbb(:,[indeksKnn])=[];
Kbb([indeksKnn],:)=[];

%Tvorjenje kondenzirane togostne matrike stene
Kc=Kbb-Kbn*inv(Knn)*Knb;

%Tvorjenje kondenzirane togostne matrike jedra v lokalnem koordinatnm sistemu. 
%Upostevane so po tri prostosne stopnje v posamezni etazi: dve translaciji 
%v ravnini plosce in rotacija okoli navpicne osi.
for i=1:sts(el)
    indeks123(1:n(el),i)=[[i:sts(el):n(el)*sts(el)-(sts(el)-i)]];
end
for i=1:3
    A(:,:,i)=zeros(N);
end
for i=1:sts(el)
    for j=1:n(el)
        for k=1:n(el)
            A(k,j,i)=A(k,j,i)+Kc(indeks123(k,i),indeks123(j,i));
        end
    end
end
Kl(:,:,el)=[A(:,:,1)  zeros(N)  zeros(N);...
            zeros(N)  A(:,:,2)  zeros(N);...
            zeros(N)  zeros(N)  A(:,:,3)];
             
if alfa(el)==90
    s=1;
    c=0;
elseif alfa(el)==270
    s=-1;
    c=0;
else
    s=sin(alfa(el)*pi/180);
    c=cos(alfa(el)*pi/180);
end

%tvorjenje transformacijskih matrik
Tr(:,:,el)=[c*eye(N)  s*eye(N) zeros(N);...
           -s*eye(N)  c*eye(N) zeros(N);...
            zeros(N)  zeros(N) eye(N) ];

To(:,:,el)=[eye(N)    zeros(N) -Y(el)*eye(N);...
            zeros(N)  eye(N)    X(el)*eye(N);...
            zeros(N)  zeros(N)  eye(N)];

%Tvorjenje kondenzirane togostne matrike stene v globalnem koordinatenem sistemu.
Ko(:,:,el)=(To(:,:,el))'*((Tr(:,:,el))'*Kl(:,:,el)*Tr(:,:,el))*To(:,:,el);

%Racun koordinat elementov
Xel([1:n(el)],1,el)=diag(zeros(n(el)));  %zacetno vozlisce
Yel([1:n(el)],1,el)=[0 cumsum(H(1:(n(el)-1)))]';
Xel([1:n(el)],2,el)=diag(zeros(n(el))); %koncno vozlisce
Yel([1:n(el)],2,el)=[cumsum(H)]';   

%Tvorjenje smernih vektorjev
for i=1:n(el)
    esx(i,[1 2],el)=[0 1];
    esy(i,[1 2],el)=[-1 0];
end
        
%tvorjenje razdalj od zacetnih vozlisc l
for i=1:n(el)
    lp(i,[1:11],el)=[0:0.1:1].*H(i);
end
