function DodajMase

%DEFINICIJA
%   
%   Funkcija "GlobalnaMasnaMatrika" prejme podatke o masah in tezisc
%   posameznih etaz in vrne masno matriko konstrukcije v globalnem 
%   koordinatnem sistemu. 
%
%VHODNI PODATKI
%
% - Mase: Spremenljivka je vektor. Posamezne komponente pomenijo mase v
%   pripadajocih etazah konstrukcije.
%  
% - MasVztrMom: Spremenljivka je vektor. Posamezne komponente pomenijo masne 
%   vztrajnostne momente v pripadajocih etazah konstrukcije.
%   
% - TezisceX: Spremenljivka je vektor. Posamezne komponente pomenijo
%   X koordinate tezisca mas v pripadajoci etazi glede na globalni koordinatni
%   sistem.
%
% - TezisceY: Spremenljivka je vektor. Posamezne komponente pomenijo
%   Y koordinate tezisca mas v pripadajoci etazi glede na globalni koordinatni
%   sistem.
%
% - Ekscentricnost: Spremenljivka je skalar. pomeni ekscentricnost mas
%   zaradi upotevanja sluajne ekscentrinosti
%
%IZHODNI PODATKI
%
% - M: Spremenljivka je globalna in predstavlja masno matriko konstrukcije 
%   v globalnem koordinatnem sistemu.

%definicija globalnih spremenljivk
global N
global M 
global K
global Dx
global Dy
global Xt
global Yt
global Xm
global Ym
global Xcr
global Ycr
global l
global VsotaMas
global Ptot
global stmod
global PodatkiOKonstrukciji
global RezultatiAnalize
global SmerAnalize

%Tvorjenje podmatrik transformacijske matrike ter matrik mas in
%vztrajnostnih momentov v lokalnem koordinatnem sistemu
for i=1:N
    if length(PodatkiOKonstrukciji.Mase.HorizontalnaSmer)==1
        Mtr(i,i)=PodatkiOKonstrukciji.Mase.HorizontalnaSmer;
    else
        Mtr(i,i)=PodatkiOKonstrukciji.Mase.HorizontalnaSmer(i);
    end
end
VsotaMas=sum(diag(Mtr));

for i=1:N
    if length(PodatkiOKonstrukciji.Mase.Rotacija)==1
       Mfi(i,i)=PodatkiOKonstrukciji.Mase.Rotacija;
    else
       Mfi(i,i)=PodatkiOKonstrukciji.Mase.Rotacija(i);
    end
end

%vztrajnostni polmer etae
for i=1:N
    l(i)=sqrt(Mfi(i,i)/Mtr(i,i));
end

for i=1:N
    if length(PodatkiOKonstrukciji.Mase.Tezisce(1))==1
       Xt(i,i)=PodatkiOKonstrukciji.Mase.Tezisce(1);
    else
       Xt(i,i)=PodatkiOKonstrukciji.Mase.Tezisce(1,i);
    end
end
for i=1:N
    if length(PodatkiOKonstrukciji.Mase.Tezisce(2))==1
       Yt(i,i)=PodatkiOKonstrukciji.Mase.Tezisce(2);
    else
       Yt(i,i)=PodatkiOKonstrukciji.Mase.Tezisce(2,i);
    end
end

Xt=round(Xt.*1000)./1000;
Yt=round(Yt.*1000)./1000;
 
%Ekscentricnost mas
ex=PodatkiOKonstrukciji.Mase.Ekscentricnost;
ey=PodatkiOKonstrukciji.Mase.Ekscentricnost;

%Tvorjenje koordinat prijemalia mas
for i=1:N
    if length(PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(1))==1
       Dx(i)=PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(1);
    else
       Dx(i)=PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(i);
    end
end
for i=1:N
    if length(PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(2))==1
       Dy(i)=PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(2);
    else
       Dy(i)=PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta(i);
    end
end

for i=1:N
    Xm(i,i,1)=Xt(i,i)+ex*Dx(i);
    Xm(i,i,2)=Xt(i,i)-ex*Dx(i);
    Ym(i,i,1)=Yt(i,i)+ey*Dy(i);
    Ym(i,i,2)=Yt(i,i)-ey*Dy(i);
end

%Tvorjenje transformacijske matrike
if ex==0
    stmod=1; % st. modelov je enako 1 
    To(:,:,1)=[eye(N)   zeros(N) -Yt;
               zeros(N) eye(N)    Xt;
               zeros(N) zeros(N)  eye(N)];
else
    stmod=4; % st. modelov je enako 4   
    To(:,:,1)=[eye(N)   zeros(N) -Ym(:,:,1);
               zeros(N) eye(N)    Xm(:,:,1);
               zeros(N) zeros(N)  eye(N)];
       
    To(:,:,2)=[eye(N)   zeros(N) -Ym(:,:,1);
               zeros(N) eye(N)    Xm(:,:,2);
               zeros(N) zeros(N)  eye(N)];
       
    To(:,:,3)=[eye(N)   zeros(N) -Ym(:,:,2);
               zeros(N) eye(N)    Xm(:,:,2);
               zeros(N) zeros(N)  eye(N)];
       
    To(:,:,4)=[eye(N)   zeros(N) -Ym(:,:,2);
               zeros(N) eye(N)    Xm(:,:,1);
               zeros(N) zeros(N)  eye(N)];
end

%Generiranje masne matrike konstrukcije v globalnem koordinatnem sistemu
Ml=[Mtr       zeros(N)  zeros(N);...
    zeros(N)  Mtr       zeros(N);...
    zeros(N)  zeros(N)  Mfi    ];

for i=1:stmod
    M(:,:,i)=To(:,:,i)'*Ml*To(:,:,i);
end

for i=1:N
    Ptot(i)=sum(diag(Mtr(i:N,i:N)))*9.81;
end

%Priprava podatkov za izpis za izpis rezultatov:
if stmod==1 % ce imamo en model konstrukcije:
    if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1; % analiza v obeh smereh
        if sum(Xcr(:,2)-diag(Xt))==0&&sum(Ycr(:,2)-diag(Yt))==0; % ce se center togosti ujema s teziscem
        else % ce se center togosti ne ujema s teziscem
            RezultatiAnalize.Matrike.Konstrukcija.TogostnaMatrika=K([1:3*N],[1:3*N]);
            RezultatiAnalize.Matrike.Konstrukcija.PodajnostnaMatrika=inv(K([1:3*N],[1:3*N]));
            RezultatiAnalize.Matrike.Konstrukcija.MasnaMatrika=M([1:3*N],[1:3*N]);
        end
    elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1; % analiza v smeri X
        if sum(Ycr(:,2)-diag(Yt))==0; % ce se center togosti ujema s teziscem
        else % ce se center togosti ne ujema s teziscem 
        end
    elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1; % analiza v smeri Y
        if sum(Xcr(:,2)-diag(Xt))==0; % ce se center togosti ujema s teziscem
            RezultatiAnalize.Matrike.Konstrukcija.TogostnaMatrika=K([N+1:2*N],[N+1:2*N]);
            RezultatiAnalize.Matrike.Konstrukcija.PodajnostnaMatrika=inv(K([N+1:2*N],[N+1:2*N]));
            RezultatiAnalize.Matrike.Konstrukcija.MasnaMatrika=M([N+1:2*N],[N+1:2*N]);
        else % ce se center togosti ne ujema s teziscem
        end
    end
else % ceimamo stiri modele konstrukcije
end

KontrolaTlorisnePravilnosti;    
    
