function IzracunajPotresneSileNaKonstrukcijo
%DEFINICIJA
%
%   Funkcija "PotresneSileNaKonstrukcijo" vrne vektorje obremenitve 
%   na konstrukcijo za pripadajoco nihajno obliko in smer gibanja tal.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so definirani kot globalne spremenljvike
%
% - F: Spremenljivka je definirana kot tridimenzionalni seznam, 
%   v katerem so razvrsceni vektorji obtezbe konstrukcije za vse nihajne 
%   oblike in obe smeri gibanja tal.
%
% - Fkomb: Spremenljivka je definirana kot vektor. Posamezne komponente
%   pomenijo pomike konstrukcije v pripdajocih smereh.

%Definicija globalnih spremenljivk
global N
global K
global w
global U
global F
global Fno
global FkombSrss
global FkombEc
global drxSrss
global drySrss
global drxEc
global dryEc
global Ptot
global H
global TR
global Omax
global stmod
global RezultatiAnalize
global SmerAnalize
global Xcr Ycr Xt Yt 

%Racun vektorjev obtezbe na konstrukcijo
for o=1:stmod
    for j=1:2
        for i=1:length(w)
            F(:,i,j,o)=K*U(:,i,j,o);
        end
    end
end

%Kombinacija potresnih sil zaradi vpliva nihajnih oblik (CQC)
vsota=zeros(3*N,2,stmod);
for o=1:stmod
    for k=1:2
        for l=1:3*N
            for i=1:length(w(:,o))
                for j=1:length(w(:,o))
                    ceta=0.05; %koeficient kriticnega dusenja
                    r=w(j,o)/w(i,o); %razmerje frekvenc
                    ro(i,j)=((8*ceta^2)*(1+r)*r^(3/2))/((1-r^2)^2+4*(ceta^2)*r*(1+r)^2);
                    %ro je faktor, ki defnira sklopljenost posmeznih nihajnih oblik
                    vsota(l,k,o)=vsota(l,k,o)+ro(i,j)*F(l,i,k,o)*F(l,j,k,o);
                end
            end
        end
    end
end

for o=1:stmod
    for i=1:3*N
        for j=1:2
            Fno(i,j,o)=sqrt(vsota(i,j,o)); 
            %"Fno" pomeni kombinacijo potresnih sil na konstrukcijo zaradi razlicnih nihajnih oblik
        end
    end
end

%Kombinacija zaradi razlicnih smeri vzbujanja (SRSS in EC)
for o=1:stmod
    for i=1:3*N
        FkombSrss(i,o)=sqrt((Fno(i,1,o))^2+(Fno(i,2,o))^2);
        FkombEc(1,i,o)=Fno(i,1,o)+0.3*Fno(i,2,o);
        FkombEc(2,i,o)=0.3*Fno(i,1,o)+Fno(i,2,o);        
    end
end

for o=1:stmod
    for i=1:N
        VtotSrss(1,i,o)=sum(FkombSrss(i:N,o));%prvi indeks pomeni smer obremenjevanja
        VtotSrss(2,i,o)=sum(FkombSrss(N+i:2*N,o));
        VtotEc(1,:,i,o)=[sum(FkombEc(1,i:N,o)) sum(FkombEc(1,N+i:2*N,o))]; %prvi indeks pomeni kombinacijo, drugi smer.
        VtotEc(2,:,i,o)=[sum(FkombEc(2,i:N,o)) sum(FkombEc(2,N+i:2*N,o))];        
    end
end

if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
     if any(Xcr(:,2)-diag(Xt))==0&&any(Ycr(:,2)-diag(Yt))==0; % ce ni rotacije
     else % ce je rotacija
         for i=1:stmod 
             for i=1:N
             ThetaSrss(1,i,o)=(Ptot(i)*drxSrss(i,o))/(VtotSrss(1,i,o)*H(i));
             ThetaSrss(2,i,o)=(Ptot(i)*drySrss(i,o))/(VtotSrss(2,i,o)*H(i));
             ThetaEc(1,1,i,o)=(Ptot(i)*drxEc(1,i,o))/(VtotEc(1,1,i,o)*H(i));
             ThetaEc(1,2,i,o)=(Ptot(i)*dryEc(1,i,o))/(VtotEc(1,2,i,o)*H(i));
             ThetaEc(2,1,i,o)=(Ptot(i)*drxEc(2,i,o))/(VtotEc(2,1,i,o)*H(i));
             ThetaEc(2,2,i,o)=(Ptot(i)*dryEc(2,i,o))/(VtotEc(2,2,i,o)*H(i));
             end
         end
     end
     
elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1
     if any(Xcr(:,2)-diag(Xt))==0
         for i=1:stmod
             ThetaSrss(2,i,o)=(Ptot(i)*drySrss(i,o))/(VtotSrss(2,i,o)*H(i));
             ThetaEc(1,2,i,o)=(Ptot(i)*dryEc(1,i,o))/(VtotEc(1,2,i,o)*H(i));
             ThetaEc(2,2,i,o)=(Ptot(i)*dryEc(2,i,o))/(VtotEc(2,2,i,o)*H(i));
         end
     else % ce je rotacija
     end
end

OSrss=max(max(max(ThetaSrss)));
OEc=max(max(max(max(ThetaEc))));
Omax=max(OSrss,OEc);

if Omax<=0.1
    TR=1;
elseif Omax>=0.1&&Omax<=0.2
    TR=2;
    VplivTeorijeDrugegaReda;
else
    TR=0;
end

%Priprava podatkov za izpis:
if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
    if stmod==1        
        if any(Xcr(:,2)-diag(Xt))==0&&any(Ycr(:,2)-diag(Yt))==0; % ce ni rotacije
        else % ce je rotacija
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.KombinacijaSRSS=[FkombSrss([1:3*N],1)];
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.KombinacijaEC=[FkombEc(:,[1:3*N],1)]';
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.ObremenitevX=[Fno([1:3*N],1,1)];
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.ObremenitevY=[Fno([1:3*N],2,1)];
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.Nekombinirani.ObremenitevX=[F(1:3*N,:,1,1)]; 
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.Nekombinirani.ObremenitevY=[F(1:3*N,:,2,1)];            
        end
    else % ce je vec modelov
    end
elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1
    if stmod==1        
        if any(Xcr(:,2)-diag(Xt))==0
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.KombinacijaSRSS=[FkombSrss([N+1:2*N],1)];
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.KombinacijaEC=[FkombEc(:,[N+1:2*N],1)]';
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.ObremenitevY=[Fno([N+1:2*N],2,1)];
            RezultatiAnalize.PotresneSile.Konstrukcija.Model1.Nekombinirani.ObremenitevY=[F(N+1:2*N,:,2,1)];
        else 
        end
    else 
    end
end