function IzracunajPotresneSileNaMakroelemente

%DEFINICIJA
%
%   Funkcija "PotresneSileNaMakroelemente" vrne vektorje obremenitve 
%   makroelementov za pripadajoco nihajno obliko in smer gibanja tal.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so definirani kot globalne spremenljvike
%
% - Fl: Spremenljivka je definirana kot tridimenzionalni seznam, 
%   v katerem so razvrsceni vektorji obtezbe mekroelementov za pripadajoco 
%   nihajno obliko in smer gibanja tal.
%
% - Flkomb: Spremenljivka je definirana kot vektor. Posamezne komponente
%   pomenijo pomike makroelementa v pripadajoci smeri.

%Definicija globalnih spremenljivk
global N
global Kl
global n
global m
global w
global stm
global ozm
global stp
global sts
global tor
global Ul
global Fl
global Fm
global Flno
global FlkombSrss
global FlkombEc
global stmod
global Omax
global TR
global RezultatiAnalize
global SmerAnalize

%Racun vektorjev obtezbe na makroelementih
for o=1:stmod
    for k=1:stm
        for j=1:2
            for i=1:length(w(:,o))          
                Fl(:,i,j,k,o)=Kl(:,:,k)*Ul(:,i,j,k,o);
            end
        end
    end
end

%Tvorjenje razsirjenega vektorja obtezbe.
for i=1:stm
    if ozm(i)==3 %indikator stene na stebrih 
        razseznostFm(i)=6+n(i)*3;
    elseif ozm(i)==1 %indikator okvirja
        razseznostFm(i)=(m(i)+1)*n(i)*3;
    elseif ozm(i)==2 %indikator stene
        razseznostFm(i)=n(i)*3;
    elseif ozm(i)==4 %indikator stene z odprtinami
        razseznostFm(i)=(m(i)+1)*n(i)*3;
    else %ce gre za jedro
        if tor(i)==1
           razseznostFm(i)=n(i)*5;
        else
           razseznostFm(i)=n(i)*4;
        end
    end
end

Fm=zeros(max(razseznostFm),length(w),2,stm,stmod);
for o=1:stmod
    for k=1:stm
        for j=1:2
            for i=1:length(w(:,o))
                for l=1:n(k)
                    if ozm(k)==3 %indikator stene na stebrih 
                       Fm((l-1)*3+1,i,j,k,o)=Fl(l,i,j,k,o);
                    elseif ozm(k)==1 %indikator okvirja
                          if l==1
                              Fm(1,i,j,k,o)=Fl(l,i,j,k,o);
                          else
                              Fm(sum(stp(1:(l-1),k)+1)*3+1,i,j,k,o)=Fl(l,i,j,k,o);
                          end
                    elseif ozm(k)==2 %indikator stene
                          Fm((l-1)*3+1,i,j,k,o)=Fl(l,i,j,k,o);
                    elseif ozm(k)==4 %indikator stene z odprtinami
                          if l==1
                              Fm(1,i,j,k,o)=Fl(l,i,j,k,o);
                          else
                              Fm(sum(stp(1:(l-1),k)+1)*3+1,i,j,k,o)=Fl(l,i,j,k,o);
                          end
                    else %indikator jedra
                         for s=1:sts(k)
                             if tor(k)==1
                                  if s==3 %moment okoli 3. osi
                                      Fm((l-1)*5+5,i,j,k,o)=Fl((s-1)*N+l,i,j,k,o);  
                                  elseif s==1 %sila v 1. smeri
                                      Fm((l-1)*5+1,i,j,k,o)=Fl((s-1)*N+l,i,j,k,o);
                                  else %sila v 2. smeri
                                      Fm((l-1)*5+2,i,j,k,o)=Fl((s-1)*N+l,i,j,k,o); 
                                  end
                             else
                                 if s==1 %sila v 1. smeri
                                     Fm((l-1)*4+1,i,j,k,o)=Fl((s-1)*N+l,i,j,k,o);
                                 elseif s==2 %sila v 2. smeri
                                     Fm((l-1)*4+2,i,j,k,o)=Fl((s-1)*N+l,i,j,k,o);
                                 end
                             end
                         end
                    end      
                end
            end
        end
    end
end

%Kombinacija zaradi nihajnih oblik(CQC)
vsota=zeros(3*N,2,stm,stmod);
for o=1:stmod
for k=1:stm
    for p=1:2
        for l=1:3*N
            for i=1:length(w(:,o))
                for j=1:length(w(:,o))
                    ceta=0.05; %koeficient kriticnega dusenja
                    r=w(j,o)/w(i,o); %razmerje frekvenc
                    ro(i,j)=((8*ceta^2)*(1+r)*r^(3/2))/((1-r^2)^2+4*(ceta^2)*r*(1+r)^2);
                    %ro je faktor, ki defnira sklopljenost posmeznih nihajnih oblik
                    vsota(l,p,k,o)=vsota(l,p,k,o)+ro(i,j)*Fl(l,i,p,k,o)*Fl(l,j,p,k,o);
                end
            end
        end
    end
end
end

for o=1:stmod
    for k=1:stm
        for i=1:3*N
            for j=1:2
                Flno(i,j,k,o)=sqrt(vsota(i,j,k,o)); 
                %"Flno" pomeni kombinacijo potresnih sil na makroelemeente 
                %zaradi nihajnih oblik
            end
        end
    end
end

%Kombinacija zaradi razlicnih smeri obremenjevanja(SRSS)
for o=1:stmod
    for k=1:stm
        for i=1:3*N
            FlkombSrss(i,k,o)=sqrt((Flno(i,1,k,o))^2+(Flno(i,2,k,o))^2);
            FlkombEc(1,i,k,o)=Flno(i,1,k,o)+0.3*Flno(i,2,k,o);
            FlkombEc(2,i,k,o)=0.3*Flno(i,1,k,o)+Flno(i,2,k,o);
        end
    end
end

if TR==2
   Fl=Fl.*(1/(1-Omax));
   Flno=Flno.*(1/(1-Omax));
   FlkombSrss=FlkombSrss.*(1/(1-Omax));
   FlkombEc=FlkombEc.*(1/(1-Omax));
else
end

%Priprava podatkov za izpis:
    if stmod==1
        for i=1:stm                
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaSRSS=[FlkombSrss([1:N],i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaEC=[FlkombEc(:,[1:N],i,1)]';
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.ObremenitevY=[Flno([1:N],2,i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.Nekombinirani.ObremenitevY=[Fl([1:N],:,2,i,1)];
        end
    else % ce je vec modelov
    end
    
    %Priprava podatkov za izpis:
if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
    if stmod==1        
        for i=1:stm                
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaSRSS=[FlkombSrss([1:N],i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaEC=[FlkombEc(:,[1:N],i,1)]';
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.ObremenitevX=[Flno([1:N],1,i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.ObremenitevY=[Flno([1:N],2,i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.Nekombinirani.ObremenitevX=[Fl([1:N],:,1,i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.Nekombinirani.ObremenitevY=[Fl([1:N],:,2,i,1)];           
        end
    else % ce je vec modelov
    end
elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1
    if stmod==1        
        for i=1:stm                
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaSRSS=[FlkombSrss([1:N],i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.KombinacijaEC=[FlkombEc(:,[1:N],i,1)]';
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.ObremenitevY=[Flno([1:N],2,i,1)];
            RezultatiAnalize.PotresneSile.Makroelementi(i).Model1.Nekombinirani.ObremenitevY=[Fl([1:N],:,2,i,1)];
        end
    else % ce je vec modelov
    end
end