function IzracunajPremikeMakroelementov
%DEFINICIJA
%
%   Funkcija "PomikiMakroelementov" vrne vektorje pomikov makroelementov za
%   pripadajoco nihajno obliko in smer gibanja tal. Upostevane so tri
%   prostostne stopnje v vsaki etazi in sicer dve translaciji v ravnini
%   plosce in rotacija okrog osi navpicno na plosco. Pomiki so racunani v
%   centru togosti makroelementa.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so definirani kot globalne spremenljivke.
%
% - Ul: Spremenljivka je definirana kot tridimenzionalni seznam, v katerem
%   so razvrceni vektorji pomikov makroelementa za pripadajoco nihajno
%   obliko in smer obremenjevanja konstrukcije. 

% - Ulkomb: Spremenljivka je definiran kot vektor. Posamezna komponenta
%   pomeni kombinirani pomik makroelementa v pripadajoci smeri.
%
% - Uldej: spremenljivka je definirana kot vektor. Posamezna komponenta
%   pomeni dejanski pomik makroelementa v pripadajoci smeri.

%Definicija globalnih spremenljivk
global To
global Tr
global stm
global w
global qx
global qy
global N
global Xcr Ycr Xt Yt
global U
global Ul
global UlkombSrss
global UlkombEc
global UldejSrss
global UldejEc
global Ulno
global stmod
global RezultatiAnalize
global SmerAnalize

%Racun pomikov makroelementov
for o=1:stmod
    for k=1:stm
        for j=1:2
            Ul(:,:,j,k,o)=Tr(:,:,k)*To(:,:,k)*U(:,:,j,o);     
        end
    end
end

%Kombinacija zaradi vpliva nihajnih oblik (CQC)
vsota=zeros(3*N,2,stm,stmod);
for o=1:stmod
    for k=1:stm
        for m=1:2
            for l=1:3*N
                for i=1:length(w(:,o))
                    for j=1:length(w(:,o))
                        ceta=0.05; %koeficient kriticnega dusenja
                        r=w(j,o)/w(i,o); %razmerje frekvenc
                        ro(i,j)=((8*ceta^2)*(1+r)*r^(3/2))/((1-r^2)^2+4*(ceta^2)*r*(1+r)^2);
                        %ro je faktor, ki defnira sklopljenost posmeznih nihajnih oblik
                        vsota(l,m,k,o)=vsota(l,m,k,o)+ro(i,j)*Ul(l,i,m,k,o)*Ul(l,j,m,k,o);
                    end
                end
            end
        end
    end
end

for o=1:stmod
    for k=1:stm
        for i=1:3*N
            for j=1:2
                Ulno(i,j,k,o)=sqrt(vsota(i,j,k,o)); 
                %"Ulno" pomeni kombinacijo pomikov makroelementov zaradi razlicnih nihajnih oblik
            end
        end
    end
end

%Kombinacija zaradi razlicnih smeri vzbujanja (SRSS in EC)
for o=1:stmod
    for k=1:stm
        for i=1:3*N
            UlkombSrss(i,k,o)=sqrt((Ulno(i,1,k,o))^2+(Ulno(i,2,k,o))^2);
            UlkombEc(i,k,1,o)=1.0*Ulno(i,1,k,o)+0.3*Ulno(i,2,k,o);
            UlkombEc(i,k,2,o)=0.3*Ulno(i,1,k,o)+1.0*Ulno(i,2,k,o);
        end
    end
end

%Racun dejanskih pomikov SRSS in EC
for k=1:stmod
    for j=1:stm
        UldejSrss(1:N,j,k)=qx.*UlkombSrss(1:N,j,k);
        UldejSrss(N+1:2*N,j,k)=qy.*UlkombSrss(N+1:2*N,j,k);
        UldejSrss(2*N+1:3*N,j,k)=((qx+qy)*0.5).*UlkombSrss(2*N+1:3*N,j,k);
        UldejEc(1:N,j,1,k)=qx.*UlkombEc(1:N,j,1,k);
        UldejEc(N+1:2*N,j,1,k)=qy.*UlkombEc(N+1:2*N,j,1,k);
        UldejEc(2*N+1:3*N,j,1,k)=((qx+qy)*0.5).*UlkombEc(2*N+1:3*N,j,1,k);
        UldejEc(1:N,j,2,k)=qx.*UlkombEc(1:N,j,2,k);
        UldejEc(N+1:2*N,j,2,k)=qy.*UlkombEc(N+1:2*N,j,2,k);
        UldejEc(2*N+1:3*N,j,2,k)=((qx+qy)*0.5).*UlkombEc(2*N+1:3*N,j,2,k);        
    end
end   

%Priprava podatkov za izpis:
for i=1:stm
if strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri XY')==1
    if stmod==1        
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.KombinacijaSRSS=[UlkombSrss([1:N],i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.KombinacijaEC=[squeeze(UlkombEc([1:N],i,:,1))'];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.ObremenitevX=[Ulno([1:N],1,i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.ObremenitevY=[Ulno([1:N],2,i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.Nekombinirani.ObremenitevX=[Ul([1:N],:,1,i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.Nekombinirani.ObremenitevY=[Ul([1:N],:,2,i,1)];            
    else
    end
elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri X')==1

elseif strcmp(SmerAnalize,'Konstrukcija je analizirana v smeri Y')==1
    if stmod==1        
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.KombinacijaSRSS=[UlkombSrss([1:N],i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.KombinacijaEC=[squeeze(UlkombEc([1:N],i,:,1))];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.ObremenitevY=[Ulno([1:N],2,i,1)];
        RezultatiAnalize.Premiki.Makroelementi(i).Model1.Nekombinirani.ObremenitevY=[Ul([1:N],:,2,i,1)];   
    else
    end
end
end
