function VrednostiVSpektruPospeskov
%DEFINICIJA
%
%   Funkcija "SpekterPospeskov" vrne vrednosti v spektru pospeskov v
%   odvisnosti od nihajnih casov konstrukcije. Definiran je projektni
%   spekter pospeskov za horizontalno obtezbo po EC8.
%
%VHODNI PODATKI
%   
% - MaksimalniPospesek: Spremenljivka je skalar. Predstavlja maksimalni 
%   pospesek tal.
%
% - FaktorZemljine: Spremenljivka je skalar. Njena vrednost pomeni faktor
%   zemljine, ki je upostevan v spektru pospeskov.
%
% - FaktorObnasanja: Spremenljivka je skalar. Njena vresnost pomeni faktor
%   obnasanja konstrukcije.
%
% - TB: Spremenljivka je skalar. Njena vrednost pomeni spodnjo mejo 
%   konstantnega dela spektra pospeskov.
%
% - TC: Spremenljivka je skalar. Njena vrednost pomeni zgornjo mejo 
%   konstantnega dela spektra pospeskov.
%
% - TD: Spremenljivka je skalar. Meja s katero je definiran zacetek 
%   konstantnih pomikov konstrukcije.
%
%IZHODNI PODATKI
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Sa: Spremenljivka je vektor. Posamezne komponente pomenijo vrednosti 
%   v spektru pospeskov v odvisnosti od nihajnih casov za pripadajoco 
%   nihajno obliko.

%Definicija globalnih spremenljvik
global T
global Sa  % vrednosti nihajnih oblik v spektru pospekov
global Sp  % graf spektra pospekov
global Spe % geaf elastinega spektra pospekov
global Sd  % spekter pomikov
global vrednostX
global q
global qx
global qy
global Fpart
global w
global vplivNO
global TB
global TC
global TD
global ag
global S
global stmod
global PodatkiOAnalizi

q=PodatkiOAnalizi.ModalnaAnaliza.SpekterFaktorObnasanja;
qx=q(1);
qy=q(2);
ag=PodatkiOAnalizi.ModalnaAnaliza.SpekterMaksimalniPospesek;

if strcmp(PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine,'A')==1
    S=1.0;
    TB=0.15;
    TC=0.4;
    TD=2.0;
elseif strcmp(PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine,'B')==1
    S=1.2;
    TB=0.15;
    TC=0.5;
    TD=2.0;
elseif strcmp(PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine,'C')==1
    S=1.15;
    TB=0.2;
    TC=0.6;
    TD=2.0; 
elseif strcmp(PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine,'D')==1
    S=1.35;
    TB=0.2;
    TC=0.8;
    TD=2.0;     
elseif strcmp(PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine,'E')==1
    S=1.4;
    TB=0.15;
    TC=0.5;
    TD=2.0;
end

%Racun vrednosti v spektru pospeskov
for j=1:stmod
    for i=1:length(T(:,j))
        if T(i,j)>=0&&T(i,j)<TB
           Sa(i,1,j)=ag*S*(2/3+(T(i,j)/TB)*(2.5/qx-2/3));
           Sa(i,2,j)=ag*S*(2/3+(T(i,j)/TB)*(2.5/qy-2/3));
        elseif T(i,j)>=TB&&T(i,j)<TC
           Sa(i,1,j)=ag*S*2.5/qx;
           Sa(i,2,j)=ag*S*2.5/qy;
        elseif T(i,j)>=TC&&T(i,j)<TD
           Sa(i,1,j)=ag*S*(2.5/qx)*(TC/T(i,j));
           if Sa(i,1,j)<0.2*ag
              Sa(i,1,j)=0.2*ag;
           else
              Sa(i,1,j)=Sa(i,1,j);
           end
           Sa(i,2,j)=ag*S*(2.5/qy)*(TC/T(i,j));
           if Sa(i,2,j)<0.2*ag
              Sa(i,2,j)=0.2*ag;
           else
              Sa(i,2,j)=Sa(i,2,j);
           end
        else
           Sa(i,1,j)=ag*S*(2.5/qx)*(TC*TD/T(i,j)^2);
           if Sa(i,1,j)<0.2*ag
              Sa(i,1,j)=0.2*ag;
           else
              Sa(i,1,j)=Sa(i,1,j);
           end
           Sa(i,2,j)=ag*S*(2.5/qy)*(TC*TD/T(i,j)^2);
           if Sa(i,2,j)<0.2*ag
              Sa(i,2,j)=0.2*ag;
           else
              Sa(i,2,j)=Sa(i,2,j);
           end           
        end
    end
end     

for i=1:stmod
    maxX(i)=ceil(max(T(:,i)));
end
maxX=max(maxX);
if maxX<=TD
   maxX=TD;
end

%graf spektra pospekov
vrednostX=[0:0.01:maxX];

for i=1:length(vrednostX)
    if vrednostX(i)>=0&&vrednostX(i)<TB
        Sp(i,1)=ag*S*(2/3+(vrednostX(i)/TB)*(2.5/qx-2/3));
        Sp(i,2)=ag*S*(2/3+(vrednostX(i)/TB)*(2.5/qy-2/3));
    elseif vrednostX(i)>=TB&&vrednostX(i)<TC
        Sp(i,1)=ag*S*2.5/qx;
        Sp(i,2)=ag*S*2.5/qy;
    elseif vrednostX(i)>=TC&&vrednostX(i)<TD
        Sp(i,1)=ag*S*(2.5/qx)*(TC/vrednostX(i));
        if Sp(i,1)<0.2*ag
            Sp(i,1)=0.2*ag;
        else
            Sp(i,1)=Sp(i,1);
        end
        Sp(i,2)=ag*S*(2.5/qy)*(TC/vrednostX(i));
        if Sp(i,2)<0.2*ag
            Sp(i,2)=0.2*ag;
        else
            Sp(i,2)=Sp(i,2);
        end        
    elseif vrednostX(i)>=TD
        Sp(i,1)=ag*S*(2.5/qx)*(TC*TD/vrednostX(i)^2);
        if Sp(i,1)<0.2*ag
           Sp(i,1)=0.2*ag;
        else
           Sp(i,1)=Sp(i,1);
        end 
        Sp(i,2)=ag*S*(2.5/qy)*(TC*TD/vrednostX(i)^2);
        if Sp(i,2)<0.2*ag
           Sp(i,2)=0.2*ag;
        else
           Sp(i,2)=Sp(i,2);
        end      
    end
end

%graf elastinega spektra pospekov
for j=1:2
for i=1:length(vrednostX)
    if vrednostX(i)>=0&&vrednostX(i)<TB
        Spe(i,j)=ag*S*(1+(vrednostX(i)/TB)*(2.5-1));
    elseif vrednostX(i)>=TB&&vrednostX(i)<TC
        Spe(i,j)=ag*S*2.5;
    elseif vrednostX(i)>=TC&&vrednostX(i)<TD
        Spe(i,j)=ag*S*(2.5)*(TC/vrednostX(i));     
    elseif vrednostX(i)>=TD
        Spe(i,j)=ag*S*2.5*(TC*TD/vrednostX(i)^2);   
    else
        break
    end
end
end

%Vrednosti v spektru pomikov
for j=1:stmod
    for i=1:length(T(:,j))
        Sd(i,1,j)=Sa(i,1,j)/(w(i,j))^2;
        Sd(i,2,j)=Sa(i,2,j)/(w(i,j))^2;
    end
end

%vpliv nihajnih oblik
for j=1:stmod
    for i=1:length(T(:,j))
        vplivNO(i,1,j)=abs(Fpart(i,1,j)*Sa(i,1,j)/(w(i,j))^2);
        vplivNO(i,2,j)=abs(Fpart(i,2,j)*Sa(i,2,j)/(w(i,j))^2);
    end
end