function StenaS
%DEFINICIJA:
%
%   Funkcija "Stena" vrne togostne in transformacijske matrike stene in 
%   podatke o geometriji. Vsi izhodni podatki so globalne spremenljivke. 
%
%VHODNI PODATKI:
%
% - MakroElement: Spremenljivka je skalar. Njena vrednost pomeni zaporedno 
%   tevilko makroelementa, ki ga podajamo v program.
%
% - koordinataX: Spremenljivka je skalar. Njena vrednost pomeni x-koordinato
%   centra togosti stene v globalnem koordinatenem sistemu konstrukcije.
%  
% - koordinataY: Spremenljivka je skalar. Njena vrednost pomeni y-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%
% - alfa: Spremenljivka je skalar. Njena vrednost pomeni kot med osjo 1
%   lokalnega koordinatnega sistema vozlisc makroelementa in osjo "X" globalnega
%   koordinatnega sistema konstrukcije. Upostevan je desnosucni
%   koordinatni sistem.
%
% - SteviloEtaz: Spremenljivka je skalar. Njena vrednost pomeni etazo objekta, 
%   do katere sega pripadajoci makroelement.
%
% - As: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo 
%   ploscine prereza stene v pripadajoci etazi.
%
% - Is: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo 
%   vztrajnostne momente prereza stene okoli osi "z" v pripadajoci etazi.
%
%IZHODNI PODATKI:
%
%   Vsi izhodni podatki so globalne spremenljivke
%
% - Ko: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v globalnem koordinatnem sistemu.
%    
% - Kl: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v lokalnem koordinatnem sistemu.  
%
% - Km: Spremenljivka pomeni togostno matriko makroelementa v lokalnem 
%   koordinatnem sistemu.  
% 
% - To: Spremenljivka pomeni transformacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)   
%
% - Tr: Spremenljivka pomeni rotacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)
%
% - ozm: Spremenljivka je skalar. Njena vrednost predstavlja vrsto
%   makroelementa, ki ga oznacuje.
%
% - ste: Spremenljivka je skalar. Njena vrednost predstavlja stevilo
%   elementov, ki sestavljajo pripadajoci makroelement

%definicija globalnih spremenljivk
global E
global G
global H
global N
global Km
global Kl
global To
global Tr
global Ko
global ste
global ozm
global n
global Aw
global Awsy
global Iwz
global X
global Y
global Xel
global Yel
global esx
global esy
global lp
global alfa
global ts
global ds
global PodatkiOKonstrukciji
global RezultatiAnalize

el=length(X)+1;
ozm(el)=2;
E=PodatkiOKonstrukciji.GlobalniPodatki.ElasticniModul;
v=PodatkiOKonstrukciji.GlobalniPodatki.PoissonovKolicnik;
G=E/(2*(1+v));
N=PodatkiOKonstrukciji.GlobalniPodatki.SteviloEtaz;
H=PodatkiOKonstrukciji.GlobalniPodatki.VisineEtaz;
X(el)=PodatkiOKonstrukciji.Makroelement(el).Pozicija(1);
Y(el)=PodatkiOKonstrukciji.Makroelement(el).Pozicija(2);
n(el)=PodatkiOKonstrukciji.Makroelement(el).SteviloEtaz;
ste(el)=PodatkiOKonstrukciji.Makroelement(el).SteviloEtaz;
alfa(el)=PodatkiOKonstrukciji.Makroelement(el).Orientiranost;
ts(el)=PodatkiOKonstrukciji.Makroelement(el).DebelinaStene;
ds(:,el)=PodatkiOKonstrukciji.Makroelement(el).SirinaStene;

%Ustvarjanje seznamov podatkov
for i=1:n(el)
    if length(ds(:,el))==1
       Aw(el,i)=ts(el)*ds(1,el);
       Awsy(el,i)=Aw(el,i)/1.2;
       Iwz(el,i)=(ts(el)*ds(1,el)^3)/12;
    else
       Aw(el,i)=ts(el)*ds(i,el);
       Awsy(el,i)=Aw(el,i)/1.2;
       Iwz(el,i)=(ts(el)*ds(i,el)^3)/12;
    end        
end

%Generiranje togostne matrike stene
W=zeros((n(el)+1)*3);
for i=1:n(el)%za vse elemente
    fiy=12*E*Iwz(el,i)/(G*Awsy(el,i)*H(i)^2);
    a=E*Aw(el,i)/H(i);
    by=12*E*Iwz(el,i)/(H(i)^3*(1+fiy));
    cy=6*E*Iwz(el,i)/(H(i)^2*(1+fiy));
    dy=(4+fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    ey=(2-fiy)*E*Iwz(el,i)/(H(i)*(1+fiy));
    w=[by   cy   0   -by   cy   0;...
       cy   dy   0   -cy   ey   0;...
       0    0    a    0    0   -a;...
      -by  -cy   0    by  -cy   0;...
       cy   ey   0   -cy   dy   0;...
       0    0   -a    0    0    a];
       W([(i-1)*3+1:(i-1)*3+6],[(i-1)*3+1:(i-1)*3+6])=W([(i-1)*3+1:(i-1)*3+6],[(i-1)*3+1:(i-1)*3+6])+w;   
end

%Tvorjenje togostne matrike podprtega makroelementa                                             
for i=1:n(el)*3                                         
    for j=1:n(el)*3                                              
        Km(i,j,el)=W(3+i,3+j);
    end
end

% tvorjenje podajnostne matrike Dlr (pomeni reducirano podajnostno matriko 
% v lokalnem koordinatnem sistemu):

% konstanten prerez stene po viini:
for i=1:n(el)
    for j=1:i
        Dlr(j,i)=(sum(H(1:j))/(G*Awsy(el,i)))+sum(H(1:j))^2*(3*sum(H(1:i))-sum(H(1:j)))/(6*E*Iwz(el,i));
        Dlr(i,j)=Dlr(j,i);
    end
end

% tvorjenje kondenzirane togostne matrike v lokalnem koordinatnem sistemu
% makroelementa:
Klr=inv(Dlr);
Kl(:,:,el)=zeros(3*N);
for i=1:n(el)
    for j=1:n(el)
        Kl(i,j,el)=Klr(i,j);
    end
end

RezultatiAnalize.Matrike.Makroelement(el).TogostnaMatrika=Kl([1:n(el)],[1:n(el)],el);
RezultatiAnalize.Matrike.Makroelement(el).PodajnostnaMatrika=inv(Kl([1:n(el)],[1:n(el)],el));

% transformacijske matrike:
if alfa(el)==90
    s=1;
    c=0;
elseif alfa(el)==270
    s=-1;
    c=0;
else
    s=sin(alfa(el)*pi/180);
    c=cos(alfa(el)*pi/180);
end

%Tvorjenje transformacijskih matrik makroelementa
Tr(:,:,el)=[c*eye(N)  s*eye(N) zeros(N);...
           -s*eye(N)  c*eye(N) zeros(N);...
            zeros(N)  zeros(N) eye(N)];

To(:,:,el)=[eye(N)    zeros(N) -Y(el)*eye(N);...
            zeros(N)  eye(N)    X(el)*eye(N);...
            zeros(N)  zeros(N)  eye(N)];

%Tvorjenje kondenzirane togostne matrike stene v globalnem koordinatenem sistemu.
Ko(:,:,el)=(To(:,:,el))'*((Tr(:,:,el))'*Kl(:,:,el)*Tr(:,:,el))*To(:,:,el);

%Racun koordinat elementov
Xel([1:1:n(el)],1,el)=diag(zeros(n(el)));  %zacetno vozlisce
Yel([1:1:n(el)],1,el)=[0 cumsum(H(1:(n(el)-1)))]';
Xel([1:1:n(el)],2,el)=diag(zeros(n(el))); %koncno vozlisce
Yel([1:1:n(el)],2,el)=[cumsum(H)]';   

%Tvorjenje smernih vektorjev
for i=1:n(el)
    esx(i,[1 2],el)=[0 1];
    esy(i,[1 2],el)=[-1 0];
end
        
%tvorjenje razdalj od zacetnih vozlisc l
for i=1:n(el)
    lp(i,[1:11],el)=[0:0.1:1].*H(i);
end