function [Ko,Kl,Km,To,Tr,m,n,PreslikavaElementa,PreslikavaVozlisca,PreslikavaVozlisca2,Ac,Acsy,Icz,Ab,Absy,Ibz,L,ozm,stp,ste,a,b,X,Y]=StenaZOdprtinami(MakroElement,koordinataX,koordinataY,Orientiranost,SteviloOdprtin,SteviloEtaz,DebelinaStene,SirinaStebrov,SirinaOdprtin,VisinaOdprtin,OdstranjeniElementi)
%DEFINICIJA:
%
%   Funkcija "StenaZOdprtinami" vrne togostne in transformacijske matrike 
%   in stene z odprtinami in podatke o geometriji. Vsi izhodni podatki so 
%   globalne spremenljivke. 

%VHODNI PODATKI:
%
% - MakroElement: Spremenljivka je skalar. Njena vrednost pomeni zaporedno 
%   tevilko makroelementa, ki ga podajamo v program.
%
% - koordinataX: Spremenljivka je skalar. Njena vrednost pomeni x-koordinato
%   centra togosti makroelementa v globalnem koordinatenem sistemu konstrukcije.
%  
% - koordinataY: Spremenljivka je skalar. Njena vrednost pomeni y-koordinato
%   centra togosti okvirja v globalnem koordinatenem sistemu konstrukcije.
%
% - alfa: Spremenljivka je skalar. Njena vrednost pomeni kot med osjo 1
%   lokalnega koordinatnega sistema vozlisc makroelementa in osjo "X" globalnega
%   koordinatnega sistema konstrukcije. Upostevan je desnosucni
%   koordinatni sistem.
%
% - SteviloOdprtin: Spremenljivka je skalar. Njena vrednost pomeni stevilo 
%   odprtin pripadajoce stene z odprtinami.
%
% - SteviloEtaz: Spremenljivka je skalar. Njena vrednost pomeni etazo objekta, 
%   do katere sega pripadajoci makroelement.
%    
% - DebelinaStene: Spremenljivka je skalar. Njena vrednost pomeni debelino
%   stene s odprtinami in je konstantna po celotni visini visini.
%   
% - SirinaStebrov: Spremenljivka je vektor. Posamezne komponente pomenijo 
%   sirine stebrov v pripadajoci vrsti.
%   
% - SirinaOdprtin: Spremenljivka je vektor. Posamezne komponente pomenijo
%   sirine odprtin v pripadajoci polju.
%    
% - VisinaOdprtin: Spremenljivka je vektor. Posamezne komponente pomenijo 
%   visine odprtin v pripadajoci etazi.
%
% - OdstranjeniElementi: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo elemente, ki se odstranijo iz osnovno definirane 
%   stene.
%
%IZHODNI PODATKI: 
%
%   Vsi izhodni podatki so globalne spremenljivke.
%
% - Ko: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v globalnem koordinatnem sistemu. 
%     
% - Kl: Spremenljivka pomeni kondenzirano togostno matriko makroelementa 
%   v lokalnem koordinatnem sistemu. 

% - Km: Spremenljivka pomeni togostno matriko makroelementa v lokalnem 
%   koordinatnem sistemu.  
% 
% - To: Spremenljivka pomeni transformacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)   
%
% - Tr: Spremenljivka pomeni rotacijsko matriko makroelementa. 
%   (zveza med premiki makroelementov in konstrukcije)
%  
% - PreslikavaElementa: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo zaporedne stevilke elementov, ki sestavljajo 
%   makroelement.
%
% - PreslikavaVozlisca: Spremenljivka je vektor. Vrednosti posameznih 
%   komponent pomenijo zaporedne stevilke vozlisc, ki sestavljajo 
%   makroelement.
%
% - ozm: Spremenljivka je skalar. Njena vrednost predstavlja vrsto
%   makroelementa, ki ga oznacuje.
%
% - stp: Spremenljivka je vektor. Vrednosti posameznih komponent pomenijo
%   stevilo polj stene z odprtinami v posamezni etazi.
%
% - ste: Spremenljivka je skalar. Njena vrednost predstavlja stevilo
%   elementov, ki sestavljajo pripadajoci makroelement.

%definicija globalnih spremenljivk
global E
global G
global H
global N
global L
global m
global n
global stm
global ste
global ozm
global stp
global a
global b
global Km
global Kl
global To
global Tr
global Ko
global Ac
global Acsy
global Icz
global Ab
global Absy
global Ibz
global PreslikavaElementa
global PreslikavaVozlisca
global PreslikavaVozlisca2
global X
global Y
global alfa

el=MakroElement;
ozm(el)=4;
X(el)=koordinataX;
Y(el)=koordinataZ;
m(el)=SteviloOdprtin;
n(el)=SteviloEtaz;
ode=OdstranjeniElementi;
alfa(el)=orinetiranost;

%Tvorjenje seznama podatkov
for i=1:m(el)
    L(el,i)=SirinaOdprtin(i);
    at(el,i)=SirinaStebrov(i)./2;
    bt(el,i)=SirinaStebrov(i+1)./2;
end
for i=1:m(el)+1
    Ac(el,i)=SirinaStebrov(i).*DebelinaStene;
    Acsy(el,i)=SirinaStebrov(i).*DebelinaStene./1.2;
    Icz(el,i)=((SirinaStebrov(i).^3).*DebelinaStene)./12;
end
for i=1:n(el)
    Ab(el,i)=1000*DebelinaStene.*(H(i)-VisinaOdprtin(i));
    Absy(el,i)=DebelinaStene.*(H(i)-VisinaOdprtin(i))./1.2;
    Ibz(el,i)=(DebelinaStene.*(H(i)-VisinaOdprtin(i)).^3)./12;
end

%Tvorjenje togostne matrike stebrov "C"
C=zeros((m(el)+1)*(n(el)+1)*3);
for j=1:n(el)
    for i=(m(el)*(j-1)+j):((m(el)+1)*j) %za vse stebre
        vrsta=i-(j-1)*(m(el)+1);
        %kontrola ali je i-ti steber odstranjen
        indeks=0;
        for k=1:length(ode)
            if ode(k)==i
                indeks=indeks+1;
            end
        end
        %racun lokalne togostne matrike i-tega stebra 
        if indeks==1
            c=zeros(6);
        else
            fiy=12*E*Icz(el,i-(j-1)*(m(el)+1))/(G*Acsy(el,i-(j-1)*(m(el)+1))*H(j)^2);
            a=E*Ac(el,i-(j-1)*(m(el)+1))/H(j);
            by=12*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)^3*(1+fiy));
            cy=6*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)^2*(1+fiy));
            dy=(4+fiy)*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)*(1+fiy));
            ey=(2-fiy)*E*Icz(el,i-(j-1)*(m(el)+1))/(H(j)*(1+fiy));
            c=[by  cy  0  -by  cy  0;...
               cy  dy  0  -cy  ey  0;...
               0   0   a   0   0  -a;...
              -by -cy  0   by -cy  0;...
               cy  ey  0  -cy  dy  0;...
               0   0  -a   0   0   a]; 
        end  
        %generiranje togostne matrike stebrov okvirja
        C([((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 (i-1)*3+(m(el)+1)*3+1 (i-1)*3+(m(el)+1)*3+2 (i-1)*3+(m(el)+1)*3+3],...
          [((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 ((i-1)*3)+(m(el)+1)*3+1 ((i-1)*3)+(m(el)+1)*3+2 ((i-1)*3)+(m(el)+1)*3+3])=...
        C([((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 (i-1)*3+(m(el)+1)*3+1 (i-1)*3+(m(el)+1)*3+2 (i-1)*3+(m(el)+1)*3+3],...
          [((i-1)*3)+1 ((i-1)*3)+2 ((i-1)*3)+3 ((i-1)*3)+(m(el)+1)*3+1 ((i-1)*3)+(m(el)+1)*3+2 ((i-1)*3)+(m(el)+1)*3+3])+c;
    end
end

%Generiranje togostne matrike preck "B"
B=zeros((m(el)+1)*(n(el)+1)*3);
for i=1:n(el) %i-ta etaza
    for j=((m(el)+1)*n(el))+(i-1)*m(el)+1:((m(el)+1)*n(el))+m(el)*i %j-ti element
        polje=j-(i-1)*m(el)-(m(el)+1)*n(el);
        indeks=0;
        for k=1:length(ode)
            if ode(k)==j
                indeks=indeks+1;
            end
        end
        %racun lokalne togostne matrike j-tega elementa - 
        %pomeni precko "j-stevilo stebrov"
        if indeks==1
            bet=zeros(6);
        else    
            fiy=12*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(G*Absy(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^2);
            a=E*Ab(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/L(el,j-(i-1)*m(el)-(m(el)+1)*n(el));
            by=12*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^3*(1+fiy));
            cy=6*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))^2*(1+fiy));
            dy=(4+fiy)*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*(1+fiy));
            ey=(2-fiy)*E*Ibz(el,j-(i-1)*m(el)-(m(el)+1)*n(el))/(L(el,j-(i-1)*m(el)-(m(el)+1)*n(el))*(1+fiy));
            
            be=[a   0    0   -a    0   0;...
                0   dy  -cy   0    ey  cy;...
                0  -cy   by   0   -cy -by;...
               -a   0    0    a    0   0;...
                0   ey  -cy   0    dy  cy;...
                0   cy  -by   0    cy  by];          
            
            R=[1  0  0  0  0  0;...
               0  1  at(el,polje) 0  0  0;...
               0  0  1  0  0  0;...
               0  0  0  1  0  0;...
               0  0  0  0  1 -bt(el,polje);...
               0  0  0  0  0  1];
            
            bet=R'*be*R;
        end
        %generiranje togostne matrike preck stene z odprtinami
        B([(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6],...
          [(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6])=...
        B([(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6],...
          [(j-(m(el)+1)*n(el)+(m(el)+i-1))*3+1 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+2 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+3 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+4 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+5 (j-(m(el)+1)*n(el)+(m(el)+i-1))*3+6])+bet;
    end
end

%Tvorjenje togostne matrike stene z odprtinami
Knepodprto=C+B;

%Iskanje nicelnih oz. nenicelnih komponent na diagonali tog. matrike  
for i=1:(m(el)+1)*(n(el)+1)*3
    if Knepodprto(i,i)>0
        IndikatorProstostnihStopenj(i)=1;
    else
        IndikatorProstostnihStopenj(i)=0;
    end
end

%Upostevanje podprtih in odstranjenih vozlisc
for i=1:(m(el)+1)*(n(el)+1)*3
    if i<=(m(el)+1)*3
         UpostevaneProstostneStopnje(i)=0;
    else 
         UpostevaneProstostneStopnje(i)=IndikatorProstostnihStopenj(i);
    end
end

%Tvorjenje togostne matrike podprtega makroelementa
indeks=find(UpostevaneProstostneStopnje==1);
for i=1:sum(UpostevaneProstostneStopnje)
    for j=1:sum(UpostevaneProstostneStopnje)
        Km(i,j,el)=Knepodprto(indeks(i),indeks(j));
    end
end

%Razdelitev na bistvene in nebistvene prostostne stopnje
Knn=Km(:,:,el);
Knn(:,1:3:end-2)=[];
Knn(1:3:end-2,:)=[];

Knb=Km(:,:,el);
Knb(:,3:3:end)=[];
Knb(:,2:2:end)=[];
Knb(1:3:end)-2,:)=[]; 

Kbn=Km(:,:,el);
Kbn(:,1:3:end-2)=[];
Kbn(3:3:end,:)=[];
Kbn(2:2:end,:)=[];

Kbb=Km([1:3:end-2],[1:3:end-2],el);

%Tvorjenje kondenzirane togostne matrike okvirja
Kc=Kbb-Kbn*inv(Knn)*Knb;

%Priprava matrike za doloevanje kondenzirane togostne matrike z
%upotevanjem enakosti etanih pomikov
NenicelneVrstice=find(IndikatorProstostnihStopenj((m(el)+1)*3+1:(m(el)+1)*(n(el)+1)*3));
NenicelneVrstice=NenicelneVrstice(3:3:length(NenicelneVrstice))./3;
Kc2=zeros((m(el)+1)*n(el));
for i=1:length(NenicelneVrstice)
    for j=1:length(NenicelneVrstice)
        Kc2(NenicelneVrstice(i),NenicelneVrstice(j))=Kc2(NenicelneVrstice(i),NenicelneVrstice(j))+Kc(i,j);
    end
end

%Tvorjenje kondenzirane matrike makroelementa v lokalnem koordinatnem sistemu.
%Upostevane so po tri prostostne stopnje v posamezni etazi: dve translaciji
%v ravnini plosce in rotacija okoli navpicne osi.
Kl(:,:,el)=zeros(3*N);
for i=1:n(el)
    for j=1:n(el)
        for k=1:(m(el)+1)
            d=Kc2([(i-1)*(m(el)+1)+1:(m(el)+1)*i],(j-1)*(m(el)+1)+k);
            Kl(i,j,el)= Kl(i,j,el)+sum(d);
        end
    end
end

if alfa(el)==90
    s=1;
    c=0;
elseif alfa(el)==270
    s=-1;
    c=0;
else
    s=sin(alfa(el)*pi/180);
    c=cos(alfa(el)*pi/180);
end

%Tvorjenje transformacijskih matrik makroelementa
To(:,:,el)=[eye(N)    zeros(N) -Y(el)*eye(N);...
            zeros(N)  eye(N)    X(el)*eye(N);...
            zeros(N)  zeros(N)  eye(N)];
      
Tr(:,:,el)=[c*eye(N)   s*eye(N)  zeros(N);...
           -s*eye(N)   c*eye(N)  zeros(N);...
            zeros(N)   zeros(N)  eye(N)];
      
%Tvorjenje kondenzirane togostne matrike makroelementa v globalnem 
%koordinatenem sistemu.            
Ko(:,:,el)=(To(:,:,el))'*((Tr(:,:,el))'*Kl(:,:,el)*Tr(:,:,el))*To(:,:,el);

%Preslikave elementov
if length(ode)==0
    ElementFiktivni=[1:(m(el)+1)*n(el)+m(el)*n(el)];
    for i=1:((m(el)+1)*n(el)+m(el)*n(el))
        PreslikavaElementa(i,el)=i;
    end
else
    UpostevaniElementi=diag(ones((m(el)+1)*n(el)+m(el)*n(el)));
    UpostevaniElementi([ode])=0;
    ElementFiktivni=find(UpostevaniElementi);
    for i=1:length(ElementFiktivni)   
        PreslikavaElementa(i,el)=ElementFiktivni(i);
    end
end

%Preslikave vozlisc
VozlisceFiktivno=find(IndikatorProstostnihStopenj(3:3:(m(el)+1)*(n(el)+1)*3));
for i=1:length(VozlisceFiktivno)
    PreslikavaVozlisca(i,el)=VozlisceFiktivno(i);
    PreslikavaVozlisca2(VozlisceFiktivno(i),el)=i;
end

%Tvorjenje vektorja stevila polj "stp"
IndikatorElementa([ElementFiktivni],el)=1;
for i=1:n(el)
    stp(i,el)=sum(IndikatorElementa([((i-1)*(m(el)+1)+1):((i-1)*(m(el)+1)+(m(el)+1))],el))-1;
end

%Racum stevila elementov, ki sestavljajo steno z odprtinami.
ste(el)=length(find(PreslikavaElementa(:,el)));


