function DolociGlobalnePodatke
%DEFINICIJA:
%
%   Funkcija "GlobalneSpremenljivke" vrne spremenljivke, ki veljajo za
%   celotno konstrukcijo. Te so dostopne vsem nadaljnim funkcijam, v katerih 
%   jih klicemo. To pomeni, da so definirane kot globalne spremenljivke.
%
%VHODNI PODATKI:
%
%  -VisineEtaz: Spremenljivka je vektor. Vrednost posamezne komponente
%   pomeni visino pripadajoce etaze objekta.
%
%  -SteviloMakroElementov: Spremenljivka je skalar. Njenea vradnost pomeni stevilo
%   makroelementov, ki so upotevani v potresni analizi.
%
%  -ElasticniModul: Spremenljivka je skalar. Njena vrednost pomeni elastini modul
%   materiala konstrukcije.
%
%  -PoissonovoStevilo: Spremenljivka je skalar. Njena vrednost pomeni
%   poissonov stevilo materiala konstrukcije.
%
%IZHODNI PODATKI: 
%
%   Izhodni podatki so definirani kot globalne spremenljivke.
%
%   N: Spremenljivka je skalar. Vrednost predstavlja stevilo etaz konstrukcije. 
%   H: Predstavlja spremenljivko "VisineEtaz" 
%   E: Predstavlja spremenljivko "ElasticniModul"
%   G: Predstavlja spremenljivko "PoissonovoStevilo"
%   stm: Predstavlja spremenljivko "SteviloMakroElementov"

global SteviloEtaz
global VisineEtaz
global ElasticniModul
global StrizniModul
global DimenzijaObjektaX
global DimenzijaObjektaY
global SteviloMakroelementov
global N
global H
global E
global G
global Dx
global Dy
global stm

N=SteviloEtaz;

for i=1:N
    if length(VisineEtaz)==1
        H(i)=VisineEtaz;
    else
        H(i)=VisineEtaz(i);
    end
end

for i=1:N
    if length(DimenzijaObjektaX(:))==1
        Dx(i)=DimenzijaObjektaX(1);
    else
        Dx(i)=DimenzijaObjektaX(i,1);
    end
end
for i=1:N
    if length(DimenzijaObjektaY(:))==1
        Dy(i)=DimenzijaObjektaY(1);
    else
        Dy(i)=DimenzijaObjektaY(i);
    end
end

E=ElasticniModul;
v=PoissonovKolicnik;
G=E/(2*(1+v));
stm=SteviloMakroElementov;