%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%VHODNI PODATKI ZA ANALIZO KONSTRUKCIJE%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

global PodatkiOKonstrukciji
global PodatkiOAnalizi
global SmerAnalize

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   1)  PODATKI O KONSTRUKCIJI: 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%       a) GLOBALNI PODATKI O KONSTRUKCIJI: 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Dx=[20]; Dy=[12]; % tlorisne fimenzije objekta v X in Y smeri
N=[2];         % stevilo etaz objekta
H1=[3.4];H2=[3];  % visine etaz
stm=[5];       % stevilo makroelementov
E=[3.0e7];         % elasticni modul
v=[0.25];         % poissonov kolicnik materiala

SmerAnalize = 'Konstrukcija je analizirana v smeri Y';

PodatkiOKonstrukciji.GlobalniPodatki.DimenzijaObjekta =      [ Dx  Dy ];
PodatkiOKonstrukciji.GlobalniPodatki.SteviloEtaz =           [ N ];
PodatkiOKonstrukciji.GlobalniPodatki.VisineEtaz =            [ H1; H2 ]; 
PodatkiOKonstrukciji.GlobalniPodatki.SteviloMakroelementov = [ stm ];
PodatkiOKonstrukciji.GlobalniPodatki.ElasticniModul =        [ E ];
PodatkiOKonstrukciji.GlobalniPodatki.PoissonovKolicnik =     [ v ];


%       b) PODATKI O MAKROELEMENTIH:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Makroelent 1 -------------------------------------------------------------

PodatkiOKonstrukciji.Makroelement(1).Ime = 'Okvir';

X=[-5]; Y=[0];                  % X in Y koordinata centra togosti 1. makroelementa
alfa=[90];                     % Orientiranost
m=[2];                        % stevilo polj okvirja
n=[2];                        % stevilo etaz okvirja
L1=[6]; L2=[6];                % dolzine polj okvirja
Ac1=[0.25]; Ac2=[0.25]; Ac3=[0.25];      % povrsine prerezov stebrov  
Acs1=[0.13333]; Acs2=[0.13333]; Acs3=[0.13333];   % strizne povrsine prerezov stebrov
Icz1=[0.0052083]; Icz2=[0.0052083]; Icz3=[0.0052083];   % vztrajnostni momenti prerezov stebrov 
Aw1=[0.25]; Aw2=[0.25];              % povrsine prerezov gred 
Aws1=[0.13333]; Aws2=[0.13333];            % strzne povrsine prerezov gred 
Iwz1=[0.0052083]; Iwz2=[0.0052083];            % vztrajnostni momenti prerezov gred

PodatkiOKonstrukciji.Makroelement(1).Pozicija =          [ X  Y ];
PodatkiOKonstrukciji.Makroelement(1).Orientiranost =     [ alfa ];
PodatkiOKonstrukciji.Makroelement(1).SteviloPolj =       [ m ];
PodatkiOKonstrukciji.Makroelement(1).SteviloEtaz =       [ n ];
PodatkiOKonstrukciji.Makroelement(1).DolzinaPolj =       [ L1  L2 ];
PodatkiOKonstrukciji.Makroelement(1).OdstranjeniElementi = [];                                                            
PodatkiOKonstrukciji.Makroelement(1).StebriA =           [ Ac1  Ac2  Ac3 ];
PodatkiOKonstrukciji.Makroelement(1).StebriAs =          [ Acs1  Acs2  Acs3 ];%.*0.5;
PodatkiOKonstrukciji.Makroelement(1).StebriIz =          [ Icz1  Icz2  Icz3 ];%.*0.5
PodatkiOKonstrukciji.Makroelement(1).GredeA =            [ Aw1  Aw2 ];
PodatkiOKonstrukciji.Makroelement(1).GredeAs =           [ Aws1  Aws2 ];%.*0.5;
PodatkiOKonstrukciji.Makroelement(1).GredeIz =           [ Iwz1  Iwz2 ];%.*0.5;

%Makroelement 2 -----------------------------------------------------------

%Makroelement 2 se od makroelementa 1 razlikuje le po poziciji v tlorisu:

X=[0]; Y=[0];   % X in Y koordinati centra togosti 2. makroelementa

PodatkiOKonstrukciji.Makroelement(2)=PodatkiOKonstrukciji.Makroelement(1);
PodatkiOKonstrukciji.Makroelement(2).Pozicija =           [ X  Y ];

%Makroelement 3 -----------------------------------------------------------

%Makroelement 3 se od makroelementa 1 razlikuje le po poziciji v tlorisu:

X=[5]; Y=[0];   % X in Y koordinati centra togosti 3. makroelementa

PodatkiOKonstrukciji.Makroelement(3)=PodatkiOKonstrukciji.Makroelement(1);
PodatkiOKonstrukciji.Makroelement(3).Pozicija =           [ X  Y ];

%Makroelement 4 -----------------------------------------------------------

PodatkiOKonstrukciji.Makroelement(4).Ime = 'Stena';

X=[-10]; Y=[0];     % X in Y koordinati centra togosti 4. makroelementa
alfa=[90];
n=[2];
t=[0.2];
d=[3.8];

PodatkiOKonstrukciji.Makroelement(4).Pozicija =        [ X  Y ];
PodatkiOKonstrukciji.Makroelement(4).Orientiranost =   [ alfa ];
PodatkiOKonstrukciji.Makroelement(4).SteviloEtaz =     [ n ];
PodatkiOKonstrukciji.Makroelement(4).DebelinaStene =   [ t ];%*0.5;
PodatkiOKonstrukciji.Makroelement(4).SirinaStene =     [ d ];

%Makroelement 5 -----------------------------------------------------------

%Makroelement 5 se od makroelementa 4 razlikuje le po poziciji v tlorisu:

X=[10]; Y=[0];     % X in Y koordinati centra togosti 5. makroelementa

PodatkiOKonstrukciji.Makroelement(5)=PodatkiOKonstrukciji.Makroelement(4);
PodatkiOKonstrukciji.Makroelement(5).Pozicija =           [ X  Y ];


%       c) PODATKI O MASAH KONSTRUKCIJE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

m1=[250.0]; m2=[250.0];%
mfi1=[0]; mfi2=[0]; %
Xt=[0]; Yt=[0];
e=[0];

PodatkiOKonstrukciji.Mase.HorizontalnaSmer =     [ m1 ; m2 ];%
PodatkiOKonstrukciji.Mase.Rotacija =             [ mfi1; mfi2  ];%
PodatkiOKonstrukciji.Mase.Tezisce =              [ Xt  Yt ];
PodatkiOKonstrukciji.Mase.Ekscentricnost =       [ e ];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   1)  DOLOITEV DINAMINE ANALIZE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%'Da' metoda se bo izvrila; 'Ne' metoda se ne bo izvrila)

PodatkiOAnalizi.ModalnaAnaliza.Aktivna='Da';   
PodatkiOAnalizi.DirektnaIntegracija.Aktivna='Da';

%       a) PODATKI O MODALNI ANALIZI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%PODATKI O SPEKTRU POSPESKOV

ag=[0.25];
TipZemljine='A';
qx=[1]; qy=[1];

PodatkiOAnalizi.ModalnaAnaliza.SpekterMaksimalniPospesek =    [ ag ];
PodatkiOAnalizi.ModalnaAnaliza.SpekterTipZemljine =           [TipZemljine];
PodatkiOAnalizi.ModalnaAnaliza.SpekterFaktorObnasanja =       [ qx  qy ];

%       a) PODATKI O DIREKTNI INTEGRACIJI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%PODATKI O DUENJU

Ed=0.05;
PodatkiOAnalizi.DirektnaIntegracija.Dusenje=[Ed];

%PODATKI O AKSELEROGRAMU

%%---------e imamo v eni datoteki vse podatke po vrstnem redu dta,x,y uporabimo:
acc=load('potres Tolmezzo.txt');

%%---------e imamo podatke od dejanskega accelelograma
% dta=0.005;
% x='1acc X ucbenik.txt';
% y='1acc Y ucbenik.txt';
% acc=pospesek(dta,x,y);
PodatkiOAnalizi.DirektnaIntegracija.AkcelerogramPospesek=[acc];

%PODATKI DOLINE KORAKA(tn[sekunde]) IN TEVILO KORAKOV (nk)  

tn=0.001;
nk=15000;
PodatkiOAnalizi.DirektnaIntegracija.Interval= [tn];
PodatkiOAnalizi.DirektnaIntegracija.SteviloKorakov=[nk];

%DOLOITEV DIREKTNE INTEGRACIJSKE METODE ('Da' metoda se bo izvrila; 'Ne' metoda se ne bo izvrila)

%KonstantniPospesek
PodatkiOAnalizi.DirektnaIntegracija.KonstantniPospesek='Da';
%LinearniPospesek
PodatkiOAnalizi.DirektnaIntegracija.LinearniPospesek='Da';
%WilsonTheta
PodatkiOAnalizi.DirektnaIntegracija.WilsonTheta='Da';
            PodatkiOAnalizi.DirektnaIntegracija.WTheta=[1.4]; %Theta > 1
%Newmark            
PodatkiOAnalizi.DirektnaIntegracija.Newmark='Da';    %Newmark=KonstantenPospeek Gamma=1/2 in Beta=1/4  
                                                    %Newmark=LinearePospeek Gamma=1/2 in Beta=1/6 
            PodatkiOAnalizi.DirektnaIntegracija.NBeta=[1/6];
            PodatkiOAnalizi.DirektnaIntegracija.NGamma=[1/2];
%Collocation            
PodatkiOAnalizi.DirektnaIntegracija.Collocation='Da'; %Collocation=Wilson Gamma=1/2 in Beta=1/6 
                                                     %Collocation=Newmark Theta=1                              
            PodatkiOAnalizi.DirektnaIntegracija.CTheta=[1.420815];%Theta=>1
            PodatkiOAnalizi.DirektnaIntegracija.CBeta=[1/6];%T/(2*(T+1))=>Beta=<(2*T^2-1)/(4*(2*T^3-1))
            PodatkiOAnalizi.DirektnaIntegracija.CGamma=[1/2];%Gamma=1/2
%Hilber, Hughes and Taylor alfa metoda            
PodatkiOAnalizi.DirektnaIntegracija.HHT='Da';  %HHT=KonstantenPospeek Alfa=0
        HHTAlfa=-0.3;                  %alfa je element med -1/3 in 0
        HHTBeta=(1-HHTAlfa)^2/4;
        HHTGamma=(1-2*HHTAlfa)/2;
            PodatkiOAnalizi.DirektnaIntegracija.HHTAlfa=[HHTAlfa];
            PodatkiOAnalizi.DirektnaIntegracija.HHTBeta=[HHTBeta];
            PodatkiOAnalizi.DirektnaIntegracija.HHTGamma=[HHTGamma];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear Dx Dy N H1 H2 stm E v X Y alfa m n L1 L2 Ac1 Ac2 Ac3 Acs1 Acs2 Acs3 Icz1 Icz2 Icz3 
clear Aw1 Aw2 Aws1 Aws2  Iwz1 Iwz2 t d m1 m2 mfi1 mfi2 Xt Yt e ag TipZemljine qx qy 
clear tn x y dta acc Ed nk HHTAlfa HHTBeta HHTGamma
